// AimPoint function by Raptorsaurus
//ver. 1.0, 2/22/06
//Usage instructions after the code

private ["_cam","_targ","_aimoff","_targpos","_targdir","_aimpos","_camPos","_camref","_GLref","_SLref","_ASL"];
private ["_xoff","_yoff","_zoff","_x","_y","_z","_alt2","_alt1","_fbx","_fby","_lrx","_lry","_H", "_Gasl"];
private ["_DX","_DY","_camDir","_aimAng","_aimDir","_aimDis", "_raimX","_raimY","_raimZ","_aimX","_aimY","_aimZ"];

// get the parameters

_cam = _this select 0;
_targ = _this select 1;
_aimoff = _this select 2;

_targpos = getPos _targ;
_targdir = getDir (vehicle _targ);
_aimPos = _targpos;

_camPos = [getPos _cam select 0, getPos _cam select 1, (getPos _cam select 2) - .381104];
_camref = "logic" createVehicle _camPos;

//Find sea level altitude of target

_GLref = "logic" createVehicle [0,0,0];
_SLref = "emptydetector" createVehicle [0,0,0];
_SLref setPos [_targpos select 0, _targpos select 1];
_ASL = _targ distance _SLref;

// set _camref to face target

_camref SetPos _camPos;
_DX = (_targpos select 0) - (getPos _camref select 0);
_DY = (_targpos select 1) - (getPos _camref select 1);
if (_DY == 0) then {_DY = .0000001};
_camDir = (atan (_DX / _DY));
if (_DY < 0) then {_camDir = _camDir + 180};
if (_camDir < 0) then {_camDir = _camDir + 360};
_camref SetDir _camDir;

// caluculate angular aimpoint offset

If (count _aimoff == 2) Then

	{
	_aimAng = _aimoff select 0;
	_aimDir = _aimoff select 1;
	_aimDis = _camref distance _targ;
	_raimZ = _aimdis * Sin _aimAng;
	_H = _aimDis * Cos _aimAng;
	_raimX = _H * Sin _aimDir;
	_raimY = _H * Cos _aimDir;
	_aimX = (_camPos select 0) + (_raimY * Sin _camDir) + (_raimX * Sin (_camDir + 90));
	_aimY = (_camPos select 1) + (_raimY * Cos _camDir) + (_raimX * Cos (_camDir + 90));
	_GLref setPos [_aimX, _aimY, 0];
	_SLref setPos [_aimX, _aimY];
	_Gasl = _GLref distance _SLref;
	_aimZ = (_ASL - _Gasl)  + _raimZ;
	_aimPos = [_aimX, _aimY, _aimZ];
	};

// calculate coordinate aimpoint offset

If (count _aimoff == 3) Then

	{
	_xoff = _aimoff select 0;
	_yoff = _aimoff select 1;
	_zoff = _aimoff select 2;
	_x = _targpos select 0;
	_y = _targpos select 1;
	_SLref setPos [_x, _y];
	_GLref setPos [_x, _y, 0];
	_alt1 = _GLref distance _SLref;
	_fbX = (_yoff * Sin _targdir);
	_fbY = (_yoff * Cos _targdir);
	_lrX = (_xoff * Sin (_targdir + 90));
	_lrY = (_xoff * Cos (_targdir + 90));
	_SLref setPos [(_fbX + _lrX + _x),(_fbY + _lrY + _y)];
	_GLref setPos [(_fbX + _lrX + _x),(_fbY + _lrY + _y), 0];
	_alt2 = _GLref distance _SLref;
	_altdif = _alt1 - _alt2;
	_zoff = _zoff + _altdif;
	_z = (_targpos select 2) + _zoff;
	_aimPos = [(_fbX + _lrX + _x),(_fbY + _lrY + _y),_z];
	};

deleteVehicle _camref;
deleteVehicle _SLref;
deleteVehicle _GLref;

_aimpos

/*---------------------------------------------------------------
AimPoint function by Raptorsaurus
ver. 1.0, 2/22/06

Determines the aimpoint position, given a unit, a target, and aim offset.  The aim offset can be either a
two dimensional array [offset direction, offset elevation] or a three dimensional array [x,y,z] where the
x, y, and z coordinates represent a position relative to the target. 
The unit can be a camera or a unit that is going to fire a weapon in a desired direction.

- Camera or unit name
- Target Object name
- Aimpoint offset [Direction, Elevation] or [x, y, z]

If the aimpoint offset is two dimensional [Direction, Elevation]:
- Directional aimpoint offset (how many degrees to the left [negative] or right [postivie] of the target)
- Elevational aimpoint offset (how many degrees above [positive] or below [negative] the target)

Example:

_cam = "camera" camcreate [0,0,0]
_targ = plane1
_aimoff = [-35, 10]

_pos = [_cam , _targ , _aimoff] call AimPoint

This will return the Aimpoint position -35 degrees (left) of _plane1 and 10 degrees above
_plane1 (from the camera point of view).  The position will be the same distance from the camera
as is _plane1 from the camera.

If the aimpoint offset is three dimensional [x, y, z]:
- x is how far to the left (negative) or right (positive) of the target.
- y is how far in front of the target (positive) or behind the target (negative)
- z is how far above the target (postive) or below the target (negative)

Example:

_cam = "camera" camcreate [0,0,0]
_targ = plane1
_aimoff = [-10, 22, -7]

_pos = [_cam , _targ , _aimoff] call AimPoint

This will return the Aimpoint position -10 m left of _plane1, 22 m in front of _plane1, and -7 m below
_plane1.

Initialize this function by putting this in your init.sqs:
AimPoint = preprocessFile "AimPoint.sqf"
---------------------------------------------------------------*/