/*---------------------------------------------------------------
AngDirDisOff function by Raptorsaurus
v. 1.1, 7/2/05 (returns both absolute position and relative position)

Returns the positional components required to place an object relative to
another object (the reference object) at a specified angle relative to the
reference object's postition, in a specified direction relative to the
object's current direction and at a specified distance from the reference
object.

The required info passed to this function is:

- Object name
- desired angle (90 [straight up] to -90 straight down]
- desired direction (0 to 360 or 180 to -180)
- distance

Example:

_obj = _plane1
_ang = -30
_dir = 270 (or -90)
_dis = 50

_PosInfo = [_obj,_ang,_dir,_dis] call AngDirDisOff

_abspos = _posInfo select 0
_relpos = _posInfo select 1

_object2 setPos _absPos

This will set the _object2 at a position 30 degrees below _plane1's current
position, to the left side of_plane1 (-90 or 270), at a distance of 50 m.
The _relpos will tell one how far _object2 is to the left, in front/behind and
above the plane.

Initialize this function by putting this in your init.sqs:
AngDirDisOff = preprocessFile "AngDirDisOff.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_obj","_dir","_ang","_H","_dis","_X","_Y","_Z","_Objpos", "_Objdir"];
private ["_SLref","_ASL","_Gsla","_GLref", "_rX", "_rY","_rZ","_ASLcomp"];

// get the parameters

_obj = _this select 0;
_ang = _this select 1;
_dir = _this select 2;
_dis = _this select 3;

// make sure _dir is valid value

if (_dir > 360) then {_dir = _dir - 360};
if (_dir < 0) then {_dir = _dir + 360};
if (_dir == 360) then {_dir = 0};

_Objpos = getPos _obj;
_Objdir = getDir _obj;

//Find sea level altitude of object

_SLref = "emptydetector" camcreate [0,0,0];
_SLref setPos [_Objpos select 0, _Objpos select 1];
_ASL = _obj distance _SLref;

// calculate vertical position offset

_rZ = _dis * Sin _ang;

// calculate horizontal distance component

_H = _dis * Cos _ang;

// calculate relative offsets in horizontal plane

_rX = _H * Sin _dir;
_rY = _H * Cos _dir;

// calculate absolute position components in horizontal plane

_X = (_Objpos select 0) + (_rY * Sin _Objdir) + (_rX * Sin (_Objdir + 90));
_Y = (_Objpos select 1) + (_rY * Cos _Objdir) + (_rX * Cos (_Objdir + 90));

//Find Sea Level Alt of the ground at the x,y posistion and compensation value for object _ASL

_GLref = "logic" camcreate [0,0,0];
_GLref setPos [_X, _Y, 0];
_SLref setPos [_X, _Y];
_Gsla = _GLref distance _SLref;
_ASLcomp = _ASL - _Gsla;
_Z = _ASLcomp + _rZ;

deleteVehicle _GLref;
deleteVehicle _SLref;

if (_Z < 0) then {_Z = 0};

// absolute and relative position values

[[_X,_Y,_Z], [_rX,_rY,_rZ]]