/*---------------------------------------------------------------
AngDirMagtoVel function by Raptorsaurus

Returns the Velocity vectors required to shoot a projectile from an object
at a specified angle relative to horizontal, in a specified
direction relative to the object's current direction.

The required info passed to this function is:

- Object name
- desired angle (90 [straight up] to -90 straight down]
- desired direction (0 to 360 or 180 to -180)
- magnitude of pojectile (its muzzel velocity)

Example:

_obj = _plane1
_ang = -30
_dir = 270 (or -90)
_mag = 900

_Vel = [_obj,_ang,_dir,_mag] call AngDirMagtoVel

_projectile setVelocity _Vel

This will set the _projectile velocity so it flys from the reference object
(in this case _plane1) at a downward angle of 30 degrees, out from the left
side of _plane1 (-90 or 270), at a speed of 900 m/s.

Initialize this function by putting this in your init.sqs:
AngDirMagtoVel = preprocessFile "AngDirMagtoVel.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_obj","_dir","_ang","_Hvel","_mag","_Xvel","_Yvel","_Zvel","_Objdir"];
private ["_ang1","_ang2","_offang"];

// get the parameters

_obj = _this select 0;
_ang = _this select 1;
_dir = _this select 2;
_mag = _this select 3;

_Objdir = getDir _obj;

//Find relative directional offset

_ang1 = _Objdir;
_ang2 = _dir;
if ((_ang1 - _ang2) > 180) then {_ang2 = _ang2 + 360};
if ((_ang2 - _ang1) > 180) then {_ang1 = _ang1 + 360};
_offang = (_ang1 + _ang2);
if (_offang >= 360) then {_offang = _offang - 360};

// calculate vertical velocity component

_Zvel = _mag * Sin _ang;

// calculate horizontal velocity component

_Hvel = _mag * Cos _ang;

// calculate velocity components in horizontal plane

_Xvel = _Hvel * Sin _offang;
_Yvel = _Hvel * Cos _offang;

// new velocity array to set projectile in dive/climb at desired angle

[_Xvel,_Yvel,_Zvel]