/*---------------------------------------------------------------
Bomblet function by Raptorsaurus

Creates bomb in user defined circular pattern. This can be used either to simulate
one big blast, or a spread out bomblet pattern. The function also returns an array
containing all the bomblets. This can be used in a script to set a velocity to the bomlets
(since functions cannot set velocities).

Parameters:

Posistion - position for center of blast pattern. To make bombs start from an elevation use
            a value greater than 0 in the z position parameter.
Bomb Type - the type of bomb (i.e. "laserguidedbomb", "shell125", ect)
Radius - 	the spread radius from the center point to the furthest out "ring" of bomblets.
Density -   how close should the bomb be to each other (the smaller the number the closer).
Elevation Increment - values above 0 will make the outer bombs start higher than the inner
		          bombs, and value less than 0 will make the outer bombs fall sooner.
Random Factor - Shifts bomb creation postion for each bomb randomly up to a specified value
	          for no random factor use 0 (zero).  Note:  The random factor should alway be less
                than the Density.
Example:

_pos = [getPos _plane select 0, getPos _plane select 1, (getPos _plane select 2) - 5]
_bomb = "laserguidedbomb"
_radius = 50
_density = 10
_elevinc = .5
_rand = 5

_bombs = [_pos, _bomb, _radius, _density, _elevinc] call Bomblet

This will make a pattern of laserguided bombs "drop" from the plane. The bombs will be
10 meters apart from each other extending to a 50 meter radius. Heaven have mercy on anyone
or thing under that plane at the time this function is called -- talk about carpet bombing! Put this
function in a script that calls it multiple times and that is just what you can simulate, "carpet bombing".
In _bombs is an array of all the bombs. You can set a downward velocity to all the bombs by adding
a line like this to the script:

{_x setVelocity [0,0,-50]} forEach _bombs 

Initialize this function by putting this in your init.sqs:
Bomblet = preprocessFile "Bomblet.sqf"
---------------------------------------------------------------*/

// declare private variables

private ["_pos", "_bomb", "_rad", "_den", "_elevinc", "_anginc"];
private ["_ang", "_elev", "_ringrad", "_x", "_y", "_bombs", "_b", "_rand"];

//get info

_pos = _this select 0;
_bomb = _this select 1;
_rad = _this select 2;
_den = _this select 3;
_elevinc = _this select 4;
_rand = _this select 5;

_elev = _pos select 2;
_ringrad = 0;

// Create bomb at center position

_b = _bomb createVehicle _pos;
_bombs = [_b];

// start making bombs in radial pattern

While {_ringrad <= _rad}
Do
{
   _ang = 0;
   _elev = _elev + _elevinc + ((Random (_rand * 2)) - _rand);
   _ringrad = _ringrad + _den;
   _anginc = (_den / _ringrad) * (180 / pi);

   While {_ang < 360}
   Do
   {
      _x = (_pos select 0) + (_ringrad * Cos _ang) + ((Random (_rand * 2)) - _rand);
      _y = (_pos select 1) + (_ringrad * Sin _ang) + ((Random (_rand * 2)) - _rand);
      _b = _bomb createVehicle [_x,_y,_elev];
      _bombs = _bombs + [_b];
      _ang = _ang + _anginc;
    };
};
_bombs
