/*---------------------------------------------------------------
ClearGround function by Raptorsaurus
v. 1.0

Determines if a straigh line path from one point to another will clear the ground.

The required info passed to this function is:

- Starting postion [x, y, x]
- Final destination position [x, y, z]
- minimum vertical clearance (how much below the path must the ground be to consider it a clear path).
- path width. The width of the path.

Example:

_spos = [getPos shooter select 0, getPos shooter select 1, (getPos shooter select 2) + 1.6]
_epos = [getPos target select 0, getPos target select 1, (getPos target select 2) + 2]
_height = .5
_width = 5

_cleargnd = [_spos, _epos, _height, _width] call ClearGround

This will return true if there is a 5 m wide line of sight that clears the ground by at least .5 meters from
the _spos to the _tpos. If any portion of the 5 m wide path comes closer than .5 m to the ground _cleargnd will
be false.

Initialize this function by putting this in your init.sqs:
ClearGround = preprocessFile "ClearGround.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_spos","_epos","_clrH","_inc","_Zref","_Pref1","_Zspos","_Zepos","_los","_rad","_rinc","_ainc"];
private ["_Hdis","_x","_y","_z","_dis","_fdis","_ang","_dir","_Dx","_Dy","_Pref2","_dang","_radcnt","_tpos"];

// get the parameters

_spos = _this select 0;
_epos = _this select 1;
_clrH = _this select 2;
_width = _this select 3;

_Zref = "emptydetector" createVehicle [0,0,0];
_Pref1 = "logic" createVehicle [0,0,0];
_Pref2 = "logic" createVehicle [0,0,0];
_los = true;

// get the distance to the final position

_Pref1 setPos _spos;
_Pref2 setPos _epos;
_fdis = _Pref1 distance _Pref2;
if (_fdis == 0) then {_fdis = .0000001};

// calculate elevation angle to position (referenced to sea level)

_Zref setPos [_spos select 0, _spos select 1];
_Zspos = _Pref1 distance _Zref;
_Zref setPos [_epos select 0, _epos select 1];
_Zepos = _Pref2 distance _Zref;
_ang = Asin ((_Zepos - _Zspos) / _fdis);

// get direction to position

_Dx = (_epos select 0) - (_spos select 0);
_Dy = (_epos select 1) - (_spos select 1);
if (_Dy == 0) then {_Dy = .0000001};
_dir = _Dx atan2 _Dy;
if (_dir < 0) then {_dir = _dir + 360};

// optimize check increments

_rad = _width / 2;
_rinc = _rad / 2;
if (_rinc < 5) then {_rinc = _rad};
if (_rinc > 5) then {_rinc = 5; _rinc = _rad / ((_rad / _rinc) - ((_rad / _rinc) % 1))};
_inc = _rinc;
if (_fdis > 1000) then {_inc = _fdis / 150};
_inc = _fdis / ((_fdis/_inc) - ((_fdis/_inc) % 1));

// check along the path for impact to the ground or the ground coming withing _clrH of the path

_dis = _inc;
While {_dis < _fdis && _los}
Do
	{
	_Hdis = _dis * cos _ang;
	_x = (_spos select 0) + (_Hdis * Sin _dir);
	_y = (_spos select 1) + (_Hdis * Cos _dir);
	_Zref setPos [_x, _y];
	_Pref2 setPos [_x, _y, 0];
	_z = (_Zspos + (_dis * sin _ang)) - (_Zref distance _Pref2);
	if (_z < _clrH) then {_los = false};
	_radcnt = _rinc;
	While {_radcnt <= _rad && _los && _radcnt > 0}
	Do
		{
		_ainc = 180;
		_dang = _dir - 90;
		While {_dang <= (_dir + 90) && _los}
		Do
      		{
			_tpos = [(_x + (_radcnt * Sin _dang)), (_y + (_radcnt * Cos _dang))];
			_Zref setPos [_tpos select 0, _tpos select 1];
			_Pref2 setPos [_tpos select 0, _tpos select 1, 0];
			_z = (_Zspos + (_dis * sin _ang)) - (_Zref distance _Pref2);
			if (_z < _clrH) then {_los = false};
			_dang = _dang + _ainc;
			};
		_radcnt = _radcnt + _rinc;
		};
	_dis = _dis + _inc;
	};
deleteVehicle _Zref;
deleteVehicle _Pref1;
deleteVehicle _Pref2;
_los