/*---------------------------------------------------------------
ClosestObjToLine function by Raptorsaurus

Given any array of objects, this function will determine which
object is closest to a defined line segment and the perpendicular
distance from the point to the line. The line can be defined by
either two points or a starting point, a distance, a direction,
and an angle.

Required Parameters, start point, end point version:

- Starting position
- Ending position
- Array of objects

Required Parameters, start point, distance, direction, angle version

- Starting position
- Distance
- Direction (compass heading)
- Angle (off horizontal [90 is straight up, -90 is straint down])
- Array of objects

Example 1 (line defined by start point, end point):

_objdis = [_StartPos, _EndPos, [_posA,_posB,_posC]] call ClosestObjToLine

_obj = _posdis select 0
_dis = _posdis select 1

_obj will be whichever of the given objects is closest to the line.
_dis will be the perpendicular distance from the _obj to the line.

Example 2 (line defined by start point, distance, direction, angle):

_objdis = [_StartPos,_Dis,_Dir,_Ang, [_posA,_posB,_posC]] call ClosestObjToLine

_obj = _posdis select 0
_dis = _posdis select 1

_obj will be whichever of the given objects is closest to the line.
_dis will be the perpendicular distance from the _obj to the line.

Initialize this function by putting this in your init.sqs:
ClosestObjToLine = preprocessFile "ClosestObjToLine.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_spos","_dis","_dir","_ang","_objs","_SLref","_GLref","_cnt","_seg","_objInfo","_x","_y","_H","_z"];
private ["_epos","_deltaX","_deltaY","_sASL","_eASL","_Dalt","_Dref","_disT","_Zoff"];

// make reference tools
_SLref = "emptydetector" createVehicle [0,0,0];
_GLref = "logic" createVehicle [0,0,0];
_Dref = "logic" camcreate [0,0,0];

_spos = _this select 0;
//Calculate ASL at _spos
_SLref setPos [_spos select 0, _spos select 1];
_GLref setPos [_spos select 0, _spos select 1, _spos select 2];
_sASL = _SLref distance _GLref;

if (count _this > 3)
	then
	{
	_dis = _this select 1;
	_dir = _this select 2;
	_ang = _this select 3;
	_objs = _this select 4;
	}
	else
	{
	_epos = _this select 1;
	_objs = _this select 2;
	//Get heading from _spos to _epos
	_deltaX = (_epos select 0) - (_spos select 0);
	_deltaY = (_epos select 1) - (_spos select 1);
	if (_deltaY == 0) then {_deltaY = .0000001};
	_dir = _deltaX atan2 _deltaY;
	if (_dir < 0) then {_dir = _dir + 360};
	//Calculate ASL at _epos
	_SLref setPos [_epos select 0, _epos select 1];
	_GLref setPos [_epos select 0, _epos select 1, _epos select 2];
	_eASL = _SLref distance _GLref;
	// calculate delta altitude
	_Dalt = _eASL - _sASL;
	// get distance from _spos to _epos
	_GLref setPos [_spos select 0, _spos select 1, _spos select 2];
	_Dref setPos [_epos select 0, _epos select 1, _epos select 2];
	_Dis = _GLref Distance _Dref;
	// get relative angle to target
	if (_Dis < abs _Dalt) then {_Dis = abs _Dalt};
	if (_Dis == 0) then {_Dis = .0000001};
	_ang = Asin (_Dalt/_Dis);
	};

//Find which object is closest to the line

_cnt = 0;
_disT = 999999999999999999999999;

While {_cnt < count _objs} Do
	{
	_GLref setPos _spos;
	_Z = (_GLref distance (_objs select _cnt)) * Sin _ang;
	_H = (_GLref distance (_objs select _cnt)) * Cos _ang;
	_X = (_spos select 0) + (_H * Sin _dir);
	_Y = (_spos select 1) + (_H * Cos _dir);
	_GLref setPos [_X, _Y, 0];
	_SLref setPos [_X, _Y];
	_Z = _Z + (_sASL - (_GLref distance _SLref));
	_GLref setPos getPos (_objs select _cnt);
	_Zoff = _GLref distance (_objs select _cnt);
	_GLref setPos [_X, _Y, (_Z - _Zoff)];
	if (_GLref distance (_objs select _cnt) < _disT) then {_disT = _GLref distance (_objs select _cnt); _objInfo = [(_objs select _cnt),_disT]};
	_cnt = _cnt + 1;
	};

deleteVehicle _GLref;
deleteVehicle _SLref;
deleteVehicle _Dref;

_objInfo