/*---------------------------------------------------------------
CrewCapacity function by Raptorsaurus

Returns the total crew capacity of a vehicle as a six element array. The frist
element represent the dirver position, the second element is the gunner position,
the third is the commander position the forth element is the capacity of the cargo, the
fith element is the number of seats available in the cargo and the sixth element is the
total number of open seats (including control postions). If a position is not available
then the value will be 0 in the coresponding array element position. If the position is not
valid then the value will be a -1 in the coresponding array element pos. For example, a
standard empty BIS BMP would return [1,1,1, 6, 6, 9] because it has 1 driver postion, 1
gunner position, 1 commander postion and 6 cargo positions with all 9 postitions open.
An empty Mi-24 would yeild [1,1,-1,8,8, 10] (1 driver, 1 gunner, no commander 8 cargo,
10 total). An empty M2 machine gun would be [-1,1,-1, -1, 0, 1] (no driver, 1 gunner, no
commander, no cargo, 1 total). A man will return [-1,-1,-1,-1, 0, 0]. If a BMP has a driver,
gunner and commander and 2 of the cargo slots are occupied then the return will be:
[0, 0, 0, 6, 4, 4] (The driver position is valid but occupied, the gunner is valid but occupied,
the commander is valid but occupied and the cargo has a capacity of 6 with four seats
available and there are 4 total seats open).

Pass the vehicle to the function as follows:

_cap = [vehicleName] call CrewCapacity

_cap will be the local variable name containing the array.

Initialize this function by putting this in your init.sqs:
CrewCapacity = preprocessFile "CrewCapacity.sqf"
or for a local variable put this at the start of any script using the function:
_CrewCapacity = preprocessFile "CrewCapacity.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_craft","_crew","_d","_g","_c","_carg", "_tl", "_tlcarg", "_cap", "_return", "_cargoFull", "_cavail", "_tavail"];

_craft = _this select 0;
_return = [-1,-1,-1,-1, 0, 0];
_carg = [];
_tlcarg = [];
_cap = 0;
_cavail = 0;
_tavail = 0;
_cargoFull = false;
_crew = crew _craft;
_d = driver _craft;
_g = gunner _craft;
_c = commander _craft;
_carg = _crew - [_d, _g, _c];
_cap = count _carg;

//determine driver, gunner, commander capacities
if ((format ["%1", _d]) != "<NULL-object>" && alive _d) then {_return set [0, 0]} else
	{
	_tl = "logic" createVehicle [0,0,0];
	_tl moveInDriver _craft;
	if (_tl in _craft) then {_return set [0, 1]; _tavail = _tavail + 1};
	unassignVehicle _tl;
	_tl setPos [0,0,0];
	deleteVehicle _tl;
	};
if ((format ["%1", _g]) != "<NULL-object>" && alive _g) then {_return set [1, 0]} else
	{		
	_tl = "logic" createVehicle [0,0,0];
	_tl moveInGunner _craft;
	if (_tl in _craft) then {_return set [1, 1]; _tavail = _tavail + 1};
	unassignVehicle _tl;
	_tl setPos [0,0,0];
	deleteVehicle _tl;
	};
if ((format ["%1", _c]) != "<NULL-object>" && alive _c) then {_return set [2, 0]} else
	{
	_tl = "logic" createVehicle [0,0,0];
	_tl moveInCommander _craft;
	if (_tl in _craft) then {_return set [2, 1]; _tavail = _tavail + 1};
	unassignVehicle _tl;
	_tl setPos [0,0,0];
	deleteVehicle _tl;
	};

//determine cargo availability
While {! _cargoFull} Do
	{		
	_tl = "logic" createVehicle [0,0,0];
	_tl moveInCargo _craft;
	if (_tl in _craft) then {_tlcarg = _tlcarg + [_tl]} else {_cargoFull = true; deleteVehicle _tl};
	};
_cavail = count _tlcarg;
_tavail = _tavail + _cavail;
_cap = _cap + _cavail;
_return set [5, _tavail];
if (_cap > 0) then {_return set [3, _cap]; _return set [4, _cavail]};
{unassignVehicle _x; _x setPos [0,0,0]; deleteVehicle _x} forEach _tlcarg;

//Just in case someone checks a man's crew capacity
if (driver _craft == _craft) then {_return = [-1,-1,-1,-1, 0, 0]};

_return