/*---------------------------------------------------------------
DeltaVel function by Raptorsaurus

Given two velocity arrays, this function will return a velocity between the two according to a given averaging factor from
0 to 1. If the averaging factor is .5, the returned velocity will be the exact average of the two velocities, if the factor
is 0 then the returned velocity will be the first velocity, if it is 1 then it will be the second velocity, if it is .9 it
will be 90% toward the second velocity from the first velocity. This can be used in a loop to make a vehicle smoothly
transition to a new velocity.

The required info passed to this function is:

- Velocity 1 (the first velocity)
- Velocity 2 (the second velocity)
- Averaging Factor (value of 0 to 1; if 0 then no change to second velocity, if 1 then 100% change to second velocity)

Example:

_craft = _rocket1
_vel1 = velocity _rocket1
_vel2 = [_vel1 select 0, _vel1 select 1, (_vel2 select 2) + 50]
_vfact = .1

_newvel = [_vel1, _vel2, _vfact] call DeltaVel

The value returned will be 10% (.1) of the difference between _vel1 to _vel2 so in this case the vertical velocity will be
will be 5 m/s faster since .1 * 50 = 5.

Initialize this function by putting this in your init.sqs:
deltaVel = preprocessFile "deltaVel.sqf"
or locally in a script like this:
_deltaVel = preprocessFile "deltaVel.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_v1","_v2","_af", "_x1", "_y1", "_z1", "_x2", "_y2", "_z2", "_xf", "_yf", "_zf"];

// get the parameters

_v1 = _this select 0;
_v2 = _this select 1;
_af = _this select 2;

_x1 = _v1 select 0;
_y1 = _v1 select 1;
_z1 = _v1 select 2;
_x2 = _v2 select 0;
_y2 = _v2 select 1;
_z2 = _v2 select 2;

_xf = _x1 + ((_x2 - _x1) * _af);
_yf = _y1 + ((_y2 - _y1) * _af);
_zf = _z1 + ((_z2 - _z1) * _af);


[_xf, _yf, _zf]