/*---------------------------------------------------------------
DirAndAng function by Raptorsaurus

This function returns the movement direction of an object (its movement direction
is not necessarily its getDir value - it may be going in reverse) and its climb/dive
angle off horizontal

Pass info to the function in the following format:

_Dir_Ang = [_obj] call DirAndAng

_Dir_Ang will be an array with the first element being direction (compass heading
in 0 to 360 range) and the the second element being angle of climb/dive off
horizontal in range -90 to 90 (-90 is straight down, 90 is straight up, 0 is
horizontal to ground).

Initialize this function by putting this in your init.sqs:
DirAndAng = preprocessFile "DirAndAng.sqf"
---------------------------------------------------------------*/
private ["_obj","_Vel","_Hvel","_x","_y","_z","_Dir","_Ang"];

_obj = _this select 0;

_vel = Velocity (_this select 0);

_x = _vel select 0;
_y = _vel select 1;
_z = _vel select 2;

// convert to magnitued & angle format

_Hvel = sqrt(_x^2 + _y^2);

If (_Hvel == 0) then
{
  If (_z > 0) then {_Ang = 90};
  If (_z < 0) then {_Ang = -90};
  If (_z == 0) then {_Ang = 0};
};
If (_Hvel != 0) then {_Ang = Atan (_z/_Hvel)};

// find compass direction of object (movement direction is not necessarily the "getDir" value)

if (_Hvel != 0) then {_Dir = _x atan2 _y} else {_Dir = getDir _obj};
if (_Dir < 0) then { _Dir = _Dir + 360 };

[_Dir,_Ang]