/*---------------------------------------------------------------
DirInfo function by Raptorsaurus

This is a multiple purpose angle (compass heading) function.  It will return the
current heading of the first object, the bearing to a second object (from first
object), the heading of the second object, the shortest direction the first
object should turn to face the second object (either "CW" -- ClockWise, or
"CCW" -- counter clockwise) and how many degrees to the direction, it returns
a string that indicates if the objects are heading toward each other ("toward")
away from each other ("away") or in the same general direction ("same").
Finally it indicates whether the target object (second object) is to the
"front", the "rear" or the "side" of the first object.

Pass info to the function in the following format:

_Dirdata = [_refobj,_tarobj] call DirInfo

Here is what _Dirdata includes:

_objhead = _Dirdata select 0 -- the heading of the _refobj
_bearing = _Dirdata select 1 -- the bearing to the _tarobj
_tarhead = _Dirdata select 2 -- the heading of the _tarobj
_turndir = _Dirdata select 3 -- string value of either "CW" or "CCW"
_degoff = _Dirdata select 4 -- how many degrees to turn CW or CCW
_reldir = _Dirdata select 5 -- string value of "toward", "away" or "same"
_gendir = _Dirdata select 6 -- string value of "front", "rear" or "side"

Initialize this function by putting this in your init.sqs:
DirInfo = preprocessFile "DirInfo.sqf"
---------------------------------------------------------------*/

private ["_refobj","_tarobj","_objhead","_tarbear","_tarhead","_turndir"];
private ["_reldir","_checkval","_objbear","_tartoobj","_objtotar"];
private ["_ang1","_ang2","_testang","_gendir","_degoff"];

_refobj = _this select 0;
_tarobj = _this select 1;

_objtotar = false;
_tartoobj = true;
_reldir = "same";
_turndir = "CW";
_gendir = "side";

_objhead = getDir _refobj;
_tarhead = getDir _tarobj;

// find bearing to _tarobj

_tarbear = ((getpos _tarobj select 0) - (getpos _refobj select 0)) atan2 ((getpos _tarobj select 1) - (getpos _refobj select 1));

// find _tarobj bearing to _refobj

_objbear = ((getpos _refobj select 0) - (getpos _tarobj select 0)) atan2 ((getpos _refobj select 1) - (getpos _tarobj select 1));

// make bearings true compass heading

if (_tarbear < 0) then {_tarbear = _tarbear + 360};
if (_objbear < 0) then {_objbear = _objbear + 360};

// determine _turndir

if (_objhead <= 180) then
{
   _checkval = _objhead + 180;
   _turndir = "CCW";
   if (_tarbear > _objhead && _tarbear <= _checkval) then {_turndir = "CW"};
};
if (_objhead > 180) then
{
  _checkval = _objhead - 180;
  _turndir = "CW";
  if (_tarbear < _objhead && _tarbear >= _checkval) then {_turndir = "CCW"};
};

// determine if they are facing toward each other, away form each other or in same direction

// is the _refobj facing in general direction of _tarobj ?

_ang1 = _objhead;
_ang2 = _tarbear;
if ((_ang1 - _ang2) > 180) then {_ang2 = _ang2 + 360};
if ((_ang2 - _ang1) > 180) then {_ang1 = _ang1 + 360};
_testang = (_ang2 - _ang1);
if (_testang > 360) then {_testang = _testang - 360};
if ((abs _testang) < 90) then {_objtotar = true} else {_objtotar = false};
if ((abs _testang) <= 45) then {_gendir = "front"};
if ((abs _testang) > 45 && _testang < 135) then {_gendir = "side"};
if ((abs _testang) >= 135) then {_gendir = "rear"};
_degoff = _testang;

// is the _tarobj facing in general direction of _refobj

_ang1 = _tarhead;
_ang2 = _objbear;
if ((_ang1 - _ang2) > 180) then {_ang2 = _ang2 + 360};
if ((_ang2 - _ang1) > 180) then {_ang1 = _ang1 + 360};
_testang = Abs (_ang1 - _ang2);
if (_testang > 360) then {_testang = _testang - 360};
if (_testang < 90) then {_tartoobj = true} else {_tartoobj = false};

if (_tartoobj && _objtotar) then {_reldir = "toward"};
if (!_tartoobj && !_objtotar) then {_reldir = "away"};

_ang1 = _tarhead;
_ang2 = _objhead;
if ((_ang1 - _ang2) > 180) then {_ang2 = _ang2 + 360};
if ((_ang2 - _ang1) > 180) then {_ang1 = _ang1 + 360};
_testang = Abs (_ang1 - _ang2);
if (_testang > 360) then {_testang = _testang - 360};
if (_testang < 90) then {_reldir = "same"};

[_objhead,_tarbear,_tarhead,_turndir,_degoff,_reldir,_gendir]