/*---------------------------------------------------------------
DirOclock function by Raptorsaurus

Returns the direction to an object in clock format along with "way high", "high"
"mid", "low" or "way low" (i.e. "Enemy Hind at 10 o'clock High"  or "Target at
9 o'clock way low")

Pass the reference object and target object as follows:

_Dirdata = [_refobj,_targobj] call DirOclock

_Dirdata contains two values:

_clkHeading = _Dirdata select 0 ;(this is direction to target in clock format)
_elev = _Dirdata select 1

_elev is a string value indicating whether the target is at the same approximate level ("mid"), 
higher ("high"), lower ("low"), much higher ("way high") or much lower ("way low").

Initialize this function by putting this in your init.sqs:
DirOclock = preprocessFile "DirOclock.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_Robj","_Tobj","_dirRObj","_bearTobj","_Reldir","_clkdir"];
private ["_Dis","_SLref","_Ang","_RobjASL","_TobjASL","_Dalt","_elev"];

_Robj = _this select 0;
_Tobj = _this select 1;

_dirRobj = getDir _Robj;

// calculate bearing to target

_bearTobj = atan (((getPos _Tobj select 0) - (getPos _Robj select 0))/((getPos _Tobj select 1) - (getPos _Robj select 1)));

// set bearing to value that can be used to get relative direction

if ((getPos _Tobj select 1) - (getPos _Robj select 1) < 0) then {_bearTobj = _bearTobj + 180};
if (_bearTobj < 0) then {_bearTobj = _bearTobj + 360};

// get relative direction (from _Robj to _Tobj)

_Reldir = _bearTobj - _dirRobj;

// make sure it is in 360 degree format

if (_Reldir <= 0) then {_Reldir = _Reldir + 360};
if (_Reldir > 360) then {_Reldir = _Reldir - 360};

// Round _Reldir to nearest 30 degree increment (360 / 12 = 30)

_Reldir = (_Reldir + 15) - ((_Reldir + 15) % 30);
if (_Reldir == 0) then {_Reldir = 360};

// Now convert this to clock type

_Reldir = _Reldir / 30;

// get distance and ASL altitude info

// Put Sea level reference

_SLref = "emptydetector" camCreate [0,0,0];

//Calculate ASL of _Robj

_SLref setPos [getPos _Robj select 0, getPos _Robj select 1];
_RobjASL = _Robj distance _SLref;

//Calculate ASL of _Tobj

_SLref setPos [getPos _Tobj select 0, getPos _Tobj select 1];
_TobjASL = _Tobj distance _SLref;

//Delete the _SLref

deleteVehicle _SLref;

// calculate delta altitude

_Dalt = _TobjASL - _RobjASL;

// get distance from _Robj and _Tobj

_Dis = _Robj Distance _Tobj;

// get relative angle to target

if (_Dis == 0) then {_Dis = .000001};
_Ang = Abs(Asin (_Dalt/_Dis));

// Round angle to nearest 30 deg

_Ang = (_Ang + 15) - ((_Ang + 15) % 30);

_st = format ["%1",_Ang];
if (_st == "-1.#IND") then {_Ang = 90};

if (_TobjASL < _RobjASL) then {_Ang = -_Ang};

// return string value for relative elevation of _Tobj

if (_Ang >= 60) then {_elev = "Way High"};
if (_Ang < 60 && _Ang >= 30) then {_elev = "High"};
if (_Ang < 30 && _Ang > -30) then {_elev = "Mid"};
if (_Ang <= -30 && _Ang > -60) then {_elev = "Low"};
if (_Ang <= -60) then {_elev = "Way Low"};

[_Reldir,_elev]