/*---------------------------------------------------------------
MoveDirOff function by Raptorsaurus

This function returns the degree off-course an object is from
intercepting a second object.  Unlike the "DirOff" function, this function
uses the objects actual movement direction and NOT its facing direction
(unless it is stationary, then it uses the facing direction).

Pass info to the function in the following format:

_Angoff = [_refobj,_tarobj] call MoveDirOff

The value of _Angoff is in the range 0 to 180 or 0 to -180 degrees.
A negative off-course value indicates that the course correction
requires turning to the right and a positive number indicates that
a turn to the left is needed to intercept the target.

Initialize this function by putting this in your init.sqs:
MoveDirOff = preprocessFile "MoveDirOff.sqf"
---------------------------------------------------------------*/

private ["_refobj","_tarobj","_objhead","_tarbear","_ang1","_ang2","_degoff"];
private ["_Vel","_Hvel","_Xvel","_Yvel"];

_refobj = _this select 0;
_tarobj = _this select 1;

_vel = Velocity _refobj;

_Xvel = _vel select 0;
_Yvel = _vel select 1;

// find object speed and movement direction from velocity vectors
// (this is more reliable than using "getDir" and "Speed" commands)

_Hvel = sqrt(_Xvel^2 + _Yvel^2);

// find compass direction of object (movement direction is not necessarily the "getDir" value)

if (_Hvel != 0) then {_objhead = _Xvel atan2 _Yvel} else {_objhead = getDir _refobj};
if (_objhead < 0) then { _objhead = _objhead + 360 };

// find bearing to _tarobj

_tarbear = ((getpos _tarobj select 0) - (getpos _refobj select 0)) atan2 ((getpos _tarobj select 1) - (getpos _refobj select 1));

// make bearings true compass heading

if (_tarbear < 0) then {_tarbear = _tarbear + 360};

// Find Direction Offset

_ang1 = _objhead;
_ang2 = _tarbear;
if ((_ang1 - _ang2) > 180) then {_ang2 = _ang2 + 360};
if ((_ang2 - _ang1) > 180) then {_ang1 = _ang1 + 360};
_degoff = (_ang2 - _ang1);

_degoff