/*---------------------------------------------------------------
DisDirAng function by Raptorsaurus

Given two points this function finds the distance, direction
(compass heading) and angle (relative to horizontal) from the
first point to the second point.

_vector = [_spos, _epos] call DisDirAng

_vector will be this array: [distance, direction, angle]

Initialize this function by putting this in your init.sqs:
DisDirAng = preprocessFile "DisDirAng.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_spos","_epos","_deltaX","_deltaY","_dir","_SLref","_GLref","_sASL","_eASL","_Dalt","_Dref","_Dis","_Ang"];

_spos = _this select 0;
_epos = _this select 1;

// calculate point to point bearing

_deltaX = (_epos select 0) - (_spos select 0);
_deltaY = (_epos select 1) - (_spos select 1);

if (_deltaY == 0) then {_deltaY = .0000001};

_dir = _deltaX atan2 _deltaY;

if (_dir < 0) then {_dir = _dir + 360};

//Calculate ASL at _spos

_SLref = "emptydetector" camCreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];
_SLref setPos [_spos select 0, _spos select 1];
_GLref setPos [_spos select 0, _spos select 1, _spos select 2];
_sASL = _SLref distance _GLref;

//Calculate ASL at _epos

_SLref setPos [_epos select 0, _epos select 1];
_GLref setPos [_epos select 0, _epos select 1, _epos select 2];
_eASL = _SLref distance _GLref;

// calculate delta altitude

_Dalt = _eASL - _sASL;

// get distance from _spos to _epos

_Dref = "logic" camcreate [0,0,0];
_GLref setPos [_spos select 0, _spos select 1, _spos select 2];
_Dref setPos [_epos select 0, _epos select 1, _epos select 2];
_Dis = _GLref Distance _Dref;

// get relative angle to target

if (_Dis < abs _Dalt) then {_Dis = abs _Dalt};
if (_Dis == 0) then {_Dis = .0000001};
_Ang = Asin (_Dalt/_Dis);

deleteVehicle _GLref;
deleteVehicle _SLref;
deleteVehicle _Dref;

[_Dis,_Dir,_Ang]