/*---------------------------------------------------------------
GetPosOffObj function by Raptorsaurus
ver. 1.10, 7/28/05 (Now corrects for sea level at the offset position). 

This function gets a position relative to an object but offset from that object
according to user defined parameters.
The required info passed to this function is:

Reference object name
Front/Back offset     (positive to have position in front, negative to place behind)
Left/Right offset     (positive to have position to right, negative to place to left)
above/below offset    (positive to have position above, negative for below)
                
Example:

_refobj = _car
_offFB = -2
_offLR = -10
_offAB = 5

_pos = [_refobj,_offFB,_offLR,_offAB] call GetPosOffObj

This will return the map position 2 meters behind the _car, 10 meters to the left of the _car
and 5 meters above the _car.  The _pos will be an x,y,z array.

Initialize this function by putting this in your init.sqs:
GetPosOffObj = preprocessFile "GetPosOffObj.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_Refpos","_x","_y","_z","_Refdir","_offFB","_offLR","_offAB","_leadX","_leadY"];
private ["_leewX","_leewY","_refobj","_Zref", "_Pref", "_SLref", "_SLpos"];

_refobj = _this select 0;
_offFB = _this select 1;
_offLR = _this select 2;
_offAB = _this select 3;

_Refdir = getDir _refobj;
_Refpos = getPos _refobj;

_x = _Refpos select 0;
_y = _Refpos select 1;

// Setup position relative to _refobj

_leadX = (_offFB * Sin _Refdir);
_leadY = (_offFB * Cos _Refdir);
_leewX = (_offLR * Sin (_Refdir + 90));
_leewY = (_offLR * Cos (_Refdir + 90));

// Correct for sea level at offset position and calculate _z

_Zref = "emptydetector" createVehicle [0,0,0];
_Pref = "logic" createVehicle [0,0,0];
_Zref setPos [getPos _refobj select 0, getPos _refobj select 1];
_SLref = _refobj distance _Zref;
_Zref setPos [ (_leadX + _leewX + _x) , (_leadY + _leewY + _y) ];
_Pref setPos [ (_leadX + _leewX + _x) , (_leadY + _leewY + _y), 0 ];
_SLpos = _Pref distance _Zref;
_z = (_SLref + _offAB) - _SLpos;
deleteVehicle _Zref;
deleteVehicle _Pref;

[ (_leadX + _leewX + _x) , (_leadY + _leewY + _y) ,_z]