/*---------------------------------------------------------------
GroupCopy function by Raptorsaurus
v. 1.00 (1/27/08) 

Makes multiple copies of a group, including their weapons, magazines and skill. Optionally
you can also set the rank of units. If the rank array is not used, then the ranks will
default to leader being Leuitenant, 2nd man being Sergeant, 3rd man being Corporal and the
remaining units as Privates. The original seed group will be preserved. If the rank array
is smaller than the number of men, any men beyond the number of ranks listed will be Privates.
If the rank array is greater than the number of men, then only the ranks that correspond to
a unit will be used.

These are the ranks accepted by OFP. These are NOT case sensitive:
"Colonel", "Captain", "Major", "Lieutenant", "Sergeant", "Corporal", "Private"

The returned information is an array of the leader(s) of the new group(s).

The required info passed to this function is:

- Seed group
- Number of copies
- Optional Array: [leader rank, 2nd man rank, 3rd man rank, ect.]

Example:

_grp = group man1
_num = 3

_grpLeads = [_grp, _num, ["Captain", "Leuitenant", "Sergeant"]] call GroupCopy

This will make 3 copies of the group to which man1 belongs. The leader will be a Captain
the second unit will be a Leuitenant and the third man will be a Sergeant. All other units will
be Privates. The _grpLeads will be an array of all the leaders generated by the
function.

Initialize this function by putting this in your init.sqs:
GroupCopy = preprocessFile "GroupCopy.sqf"
---------------------------------------------------------------*/

private ["_grp","_num","_gcnt","_ucnt","_unit","_units","_mags","_weaps","_ranks","_s","_leads","_pos","_code"];
private ["_r","_ngrp"];

_grp = _this select 0;
_num = _this select 1;
_ranks = ["Leuitenant","Sergeant","Corporal"];
if (count _this > 2 && count (_this select 2) > 0) then {_ranks = _this select 2};
if (_num < 1) then {_num = 1};
_leads = [];
_gcnt = 0;

while {_gcnt < _num}
	do
	{
	_unit = leader _grp;
	_units = units _grp;
	_mags = magazines _unit;
	_weaps = weapons _unit;
	_s = skill _unit;
	_r = _ranks select 0;
	_code = format [{removeAllWeapons this; {this addMagazine _x} forEach %1; {this addWeapon _x} forEach %2},_mags,_weaps];
	[_unit] join grpNull;
	_ngrp = group _unit;
	(typeOf _unit) createUnit [getPos _unit, _ngrp, _code, _s, _r];
	[_unit] join _grp;
	(_units - [_unit]) join grpNull;
	_leads = _leads + [leader _ngrp];
	_ucnt = 1;

	while {_ucnt < count _units}
		do
		{
		_unit = _units select _ucnt;
		_mags = magazines _unit;
		_weaps = weapons _unit;
		_s = skill _unit;
		_r = "Private";
		if (_ucnt < count _ranks) then {_r = _ranks select _ucnt};
		_code = format [{removeAllWeapons this; {this addMagazine _x} forEach %1; {this addWeapon _x} forEach %2},_mags,_weaps];
		[_unit] join _grp;
		(typeOf _unit) createUnit [getPos _unit, _ngrp, _code, _s, _r];
		_ucnt = _ucnt + 1;
		};
	_gcnt = _gcnt + 1;
	};
_leads