/*---------------------------------------------------------------
HVvel function by Raptorsaurus

Returns the  Horizontal and Vertical velocity of an object as a two element
array.  Horizontal velocity is the resultant magnitude of its x & y rectangular
velociy components and Vertical velocity is the z rectangular velocity component.
For example a missile's speed may be 900 m/s but if it is going up at a 60 deg angle
its Hvel(volocity over the ground) will be 450 m/s and its Vvel (vertical velocity)
will be 779.423 m/s.  If the object is in a dive then the Zvel will be a negative
number.

Call this funciton by passing the projectile object as the parameter.
Example:
_HVvel = [_obj] call HVvel

_Hvel = _VHvel select 0
_Vvel = _VHvel select 1

Initialize this function by putting this in your mission "init.sqs" or at the start
of the first script in a mission that uses this function:

HVvel = preprocessFile "HVvel.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_vel","_x","_y","_z","_Hvel"];

_vel = Velocity (_this select 0);

// get the rectangular velocity vector components

_x = _vel select 0;
_y = _vel select 1;
_z = _vel select 2;

// get the Hvel

_Hvel = sqrt(_x^2 + _y^2);

// pass the array

[_Hvel, _z]