/*---------------------------------------------------------------
HighPoint function by Raptorsaurus (version 1.0)

Given a position, a direction, distance and check increment; this function returns the
highest terrain elevation in the given direction within the given distance.  The
returned information is an array containing the ASL altitude of the high point,  the 
differential altitude between the reference point and the high point, the differential
altitude between the reference point and the point at the greatest distance, the
horizontal distance from the reference position to the high point and the position of
the high point.

Example:

_HpInfo = [(getPos player), 65, 2000, 10] call HighPoint

_h = _HpInfo select 0	this will be the altitude above sea level of the highest
			point at 65 deg. heading from the player within 2000 m.
_hd = _HpInfo select 1	this will be the altitude difference between the ref pos and
			the high pos.  If the highest postion in the given path is lower
			than the starting pos, then this value will be negative.
_fd = _HpInfo select 2	this will be the altitude difference between the ref pos and
			the furthest pos (the point 2000 m away).  If the alt at the
			furthest distance pos is lower than the ref pos alt, then this
			value will be negative.
_d = _HpInfo select 3	this is the distance from the ref pos to the highest point.
_p = _HpInfo select 4	this is the postion of the high point (two dim position - [x,y])

Initialize this function by putting this in your init.sqs:
HighPoint = preprocessFile "HighPoint.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_rpos", "_dir", "_dis", "_inc", "_SLref", "_GLref","_ASL","_hdis", "_hpos", "_dASL", "_rASL", "_discnt", "_fASL"];

_rpos = _this select 0;
_dir = _this select 1;
_dis = _this select 2;
_inc = _this select 3;

_SLref = "emptyDetector" camcreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];
_SLref setPos [_rpos select 0, _rpos select 1];
_GLref setPos [_rpos select 0, _rpos select 1, 0];
_rASL = _GLref distance _SLref;
_ASL = -9999;
_dASL = 0;
_hdis = 0;
_hpos = _rpos;
_discnt = _inc;
While {_discnt <= _dis} Do
	{
	_SLref setPos  [(_rpos select 0) + (_discnt * sin _dir), (_rpos select 1) + (_discnt * cos _dir)];
	_GLref setPos  [(_rpos select 0) + (_discnt * sin _dir), (_rpos select 1) + (_discnt * cos _dir), 0];
	_fASL = (_GLref distance _SLref);
	if (_fASL > _ASL) then
		{
		_ASL = _fASL;
		_dASL = _ASL - _rASL;
		_hdis = _discnt;
		_hpos = [(_rpos select 0) + (_discnt * sin _dir), (_rpos select 1) + (_discnt * cos _dir)];
		};
	_discnt = _discnt + _inc;
	};

_fASL = _fASL - _rASL;
deleteVehicle _SLref;
deleteVehicle _GLref;

[_ASL, _dASL, _fASL, _hdis, _hpos]