/*---------------------------------------------------------------
ImpactPnt function by Raptorsaurus
v. 1.0

Assuming a straigh trajectory this function predicts the ground impact point of a moving object. The impact
point with the ground will be a 3D array of the impact position. If the object's trajectory will not make
the object impact the ground then the return array will be [-1,-1,-1].

The required info passed to this function is:

- Object
- The position precision

Example:

_ipos = [_obj, 1] call ImpactPnt

_ipos will be the ground impact position of the object within 1m precision.

Initialize this function by putting this in your init.sqs:
ImpactPnt = preprocessFile "ImpactPnt.sqf"
---------------------------------------------------------------*/

private ["_obj", "_dis", "_dir", "_inc", "_obj", "_Pvel", "_XvelP", "_YvelP", "_ZvelP", "_Pang", "_Hvel", "_Pspd", "_Tdis","_exca"];
private ["_discnt","_X","_Y","_Z", "_H", "_Ppos", "_objA", "_SLref", "_GLref", "_ASL", "_unit", "_disT", "_objN", "_exct"];
_obj = _this select 0;
_inc = _this select 1;

_SLref = "emptydetector" createVehicle [0,0,0];
_GLref = "logic" createVehicle [0,0,0];
_disT = 999999;

// get the velocity & pos

_Pvel = Velocity _proj;
_Ppos = getPos _proj;
_SLref setPos [_Ppos select 0, _Ppos select 1];
_ASL = _proj distance _SLref;

// get the rectangular velocity vector components

_XvelP = (_Pvel select 0);
_YvelP = (_Pvel select 1);
_ZvelP = (_Pvel select 2);

// find projectile speed and movement direction from velocity vectors
// (this is more reliable than using "getDir" and "Speed" commands)

_Hvel = sqrt(_XvelP^2 + _YvelP^2);

If (_Hvel == 0) then
{
  If (_ZvelP > 0) then {_Pang = 90};
  If (_ZvelP < 0) then {_Pang = -90};
  If (_ZvelP == 0) then {_Pang = 0};
};
If (_Hvel != 0)
then
{
  _Pang = Atan (_ZvelP/_Hvel);
  _Pspd = _Hvel / Cos _Pang;
}
Else
{
  _Pspd = abs _ZvelP;
};

// find compass direction of projectile (movement direction is not necessarily the "getDir" value)

if (_Pspd > 0) then {_dir = _XvelP atan2 _YvelP} else {_dir = getDir _proj};
if (_dir < 0) then { _dir = _dir + 360 };

// find objects along trajectory path of _proj

_discnt = _inc;
While {_discnt <= _dis} Do
   	{
	_Z = _discnt * Sin _Pang;
	_H = _discnt * Cos _Pang;
	_X = (_Ppos select 0) + (_H * Sin _dir);
	_Y = (_Ppos select 1) + (_H * Cos _dir);
	_GLref setPos [_X, _Y, 0];
	_SLref setPos [_X, _Y];
	_Z = _Z + (_ASL - (_GLref distance _SLref));
	_GLref setPos [0,0,0];
	_SLref setPos [0,0];
	if (_Z < 0) then {_Z = 0};
	_obj = nearestObject [_X, _Y, _Z];
	if (! (_obj in _objA) && _unit countEnemy [_obj] == 1 && ! ((typeOf _obj) in _exct)) then
		{
		_objA = _objA + [_obj];
		_Z = (_proj distance _obj) * Sin _Pang;
		_H = (_proj distance _obj) * Cos _Pang;
		_X = (_Ppos select 0) + (_H * Sin _dir);
		_Y = (_Ppos select 1) + (_H * Cos _dir);
		_GLref setPos [_X, _Y, 0];
		_SLref setPos [_X, _Y];
		_Z = _Z + (_ASL - (_GLref distance _SLref));
		_GLref setPos [_X, _Y, _Z];
		if (_GLref distance _obj < _disT) then {_disT = _GLref distance _obj; _objN = _obj;};
		};
	_discnt = _discnt + _inc;
	};
deleteVehicle _GLref;
deleteVehicle _SLref;
[_objA - [_proj], _objN]