/*---------------------------------------------------------------
MovePos function by Raptorsaurus
v. 1.0

Given an object, a final position, the object speed and elapsed time, this function
will place the object in a calculated postion on the path toward the final position.
Thus this function can be used in a loop to make it appear that an object is moving
at a certain speed. This is usefull for moving objects that do not respond to the
setVelocity command. This function also will return the calculated position.

The required info passed to this function is:

- Object name
- Final destination position [x, y, z]
- Simulated speed in m/s
- Elapsed time in seconds

Example:

_obj = fireball1
_pos = (getPos house)
_spd = 200
_rt = _time
#loop
_etm = _time - _rt; _rt = _time
[_obj, _pos, _spd, _etm] call MovePos
~.01
? (_obj distance house > .5) : goto "loop"

This will make the fireball1 move toward the house at a speed (simulated) of 200 m/s.
Once the fireball hits the house, the loop will end.

Initialize this function by putting this in your init.sqs:
MovePos = preprocessFile "MovePos.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_obj", "_pos", "_spd", "_tm", "_Zref", "_Pref1", "_Zobj", "_Zpos", "_opos"];
private [ "_Hdis", "_x", "_y", "_z", "_dis", "_fdis", "_ang", "_dir", "_Dx", "_Dy", "_Pref2"];

// get the parameters

_obj = _this select 0;
_pos = _this select 1;
_spd = _this select 2;
_tm = _this select 3;

_Zref = "emptydetector" createVehicle [0,0,0];
_Pref1 = "logic" createVehicle [0,0,0];
_Pref2 = "logic" createVehicle [0,0,0];
_opos = getPos _obj;

// get the distance to the final position

_Pref1 setPos _opos;
_Pref2 setPos _pos;
_fdis = _Pref1 distance _Pref2;
if (_fdis == 0) then {_fdis = .0000001};

// calculate elevation angle to position (referenced to sea level)

_Zref setPos [_opos select 0, _opos select 1];
_Zobj = _Pref1 distance _Zref;
_Zref setPos [_pos select 0, _pos select 1];
_Zpos = _Pref2 distance _Zref;
_ang = Asin ((_Zpos - _Zobj) / _fdis);

// calculate the movement distance over elapsed time (_tm)

_dis = _spd * _tm;
if (_dis > _fdis) then {_dis = _fdis};

// calculate the horizontal distance

_Hdis = _dis * cos _ang;

// get direction to position

_Dx = (_pos select 0) - (_opos select 0);
_Dy = (_pos select 1) - (_opos select 1);
if (_Dy == 0) then {_Dy = .0000001};
_dir = _Dx atan2 _Dy;
if (_dir < 0) then {_dir = _dir + 360};

// Calculate the x and y positions

_x = (_opos select 0) + (_Hdis * Sin _dir);
_y = (_opos select 1) + (_Hdis * Cos _dir);

// Calculate the z position compensated for sea level of ground at (_x, _y)

_z = _Zobj + (_dis * sin _ang);
_Zref setPos [_x, _y];
_Pref2 setPos [_x, _y, 0];
_Zpos = _Pref2 distance _Zref;
_z = _z - _Zpos;

deleteVehicle _Zref;
deleteVehicle _Pref1;
deleteVehicle _Pref2;

_obj setPos [_x, _y, _z];
[_x, _y, _z]