/*---------------------------------------------------------------
NOEang function by Raptorsaurus (Ver. 1.4)
Ver. History:
05/05/05:  Ver 1.2 - Switch to use "emptydetector" instead of "logic" for _SLref
05/21/05:  Ver 1.3 - Function now finds the angle needed to clear the highest point in its path.
12/07/05:  Ver 1.4 - Function now finds the average terrain gradiant up to the look ahead point.

See usage instructions at end of code body.
---------------------------------------------------------------*/
// declare private variables
private ["_craft","_dirCraft","_posCraft","_Radar","_craftASL","_RadarASL", "_tAng"];
private ["_crX","_crY","_AGL","_posRadar","_radX","_radY","_Ang","_Dis", "_num"];
private ["_Hdis","_st","_rRange","_Rangedar","_cnt", "_recAng","_ASL", "_avgAng"];
private ["_rDis","_SLref","_deltaAlt","_ang1","_ang2","_RangedarASL","_angoff"];

// get needed values

_craft = _this select 0;
_AGL = _this select 1;
_rDis = _this select 2;
_rRange = _this select 3;
_angoff = _this select 4;

if (_rDis < 1) then {_rDis = 1};

_posCraft = getPos _craft;
_crX = _posCraft select 0;
_crY = _posCraft select 1;

_dirCraft = (getDir _craft) + _angoff;
if (_dirCraft > 360) then {_dirCraft = _dirCraft - 360};
if (_dirCraft < 0) then {_dirCraft = _dirCraft + 360};

// put "start radar" _rDis in front of craft

_Radar = "logic" camCreate [(_crX + (_rDis * Sin _dirCraft)),(_crY + (_rDis * Cos _dirCraft)),0];

// create "range radar"

_Rangedar = "logic" camCreate [0, 0, 0];

// create Sea level reference

_SLref = "emptyDetector" camCreate [0, 0, 0];

// get radar postition

_posRadar = getPos _Radar;
_radX = _posRadar select 0;
_radY = _posRadar select 1;

//Calculate ASL of craft, ASL at Radar pos & ASL of the terrain at the craft location 

_SLref setPos [_crX, _crY];
_craftASL = _craft distance _SLref;

_Rangedar setPos [_crx, _cry, 0];
_rangedarASL = _Rangedar distance _SLref;

_SLref setPos [_radX, _radY];
_RadarASL = _Radar distance _SLref;

//Calculate the _deltaAlt between aircraft and Radar position

_deltaAlt = (_RadarASL+_AGL) - _craftASL;

//Calculate the climb/dive angle to reach _deltaAlt

_ang1 = Atan (_deltaAlt/_rDis);

// find greatest and average terrain angle in the path of craft

_recAng = 0;
_num = 1;
_tAng = 0;
_cnt = _rDis;

While {_cnt < _rRange}
Do
	{

	//place the range radar and SLref and calculate the angle to that point

	_Rangedar setPos [(_crX + (_cnt * Sin _dirCraft)),(_crY + (_cnt * Cos _dirCraft)),0];
	_SLref setPos [(_crX + (_cnt * Sin _dirCraft)),(_crY + (_cnt * Cos _dirCraft))];
	_ASL = _Rangedar distance _SLref;
	_deltaAlt = _ASL - _RangedarASL;
	_ang2 = Atan (_deltaAlt/_cnt);
	_tAng = _tAng + _ang2;

	//if _ang2 is greater than the last recorded _ang2 then record _ang2

	If (_ang2 > _recang) then {_recAng = _ang2};
	_cnt = _cnt + _rDis;
	_num = _num + 1;
	};

_ang2 = _recAng;
_avgAng = _tAng / _num	;	

//Delete the _Radar, _Rangedar and _SLref

deleteVehicle _Radar;
deleteVehicle _SLref;
deleteVehicle _Rangedar;

// Return the values

[_ang1,_ang2, _avgAng]

/*---------------------------------------------------------------
NOEang.sqf usage intructions

Returns the angle of climb/dive required for an aircraft/missile to maintain a 
given AGL altitude by looking at the terrain sea level altitude at a given 
distance ahead of the vehicle. Also can be used to get the terrain elevation 
a given distance in front of a unit (useful for artillery). 

Pass info to the function in the following format: 

_Ang = [_craft,_nomAGL,_lookaheadDis,_lookaheadRange,_angoff] call NOEang 

_craft is the name of the flying object or aircraft, _nomAGL is the nominal 
altitude Above Ground Level, _lookaheadDis is the distance to look ahead of the 
aircraft and _lookaheadRange is the distance over which the terrain gradient 
ahead of the craft will be measured.  The _angoff is the anticipated direction the
craft will be heading. In general a value of zero should be used, but one can
check the terrain elevation in any direction if so desired. This can be useful for
finding the lowest/highest elevation path or for determining the elevation of the
ground in the direction artillery is going to fire. Valid values are 0 to 360 or -180
to +180 the _angoff is relative to the vehicle's current direction, so if _angoff
= -90 or 270 the elevation to the left of the craft will be checked. A value of 30
will check the elevation 30 deg to the right of the craft's current heading etc. 

It is recommended that the look ahead distance be proportional to the aircraft's 
actual AGL altitude (not the desired nominal). This will make the climb angle 
steeper if the craft is too close to the ground and will keep the dive angle 
from being too steep if the craft is too high. 

The function returns an array of three angles that can be used. The first angle 
is the direct angle required to put the craft at the nominal AGL at the initial 
look ahead point. The second angle is the terrain gradient to the highest point 
between the initial look ahead radar point and the look ahead range beyond.  The
third angle is the average terrain gradient from the craft to the look ahead range.
One can determine the best angle to use depending on desired effect. Direct
contour following (ang1), high point avoidance (ang2) or smoother flight (ang3). 

Example: 

_LkAhead = getPos _craft select 2 

_Angs = [_craft,_nomAGL,_LkAhead,_lookaheadRange,0] call NOEang. 

_Ang1 = _Angs select 0   ;(this is the angle needed to get te craft to the desired AGL)
_Ang2 = _Angs select 1   ;(this is the angle of the terrain to the highest elevation point in front of the craft)
_Ang3 = _Angs select 2   ;(this is the average angle of the terrain in front of the craft)

Initialize this function by putting this in your init.sqs: 
NOEang = preprocessFile "NOEang.sqf"
---------------------------------------------------------------*/