/*---------------------------------------------------------------
Parachute function by Raptorsaurus

This function is specially designed for use with the animatepara made by
WizzyWig.  It sets  the Parachute relative to another object and offset from that object
according to user defined parameters.  It will also set the angle and direction of the
parachute depending on the movement direction of the parachute (this requires that
in the script calling this function, the velocity of the chute is updated in a loop).

The required info passed to this function is:

Reference object name
The parachute name
Front/Back offset     (positive to have chute placed in front, negative to place behind)
Left/Right offset     (positive to have chute placed to right, negative to place to left)
above/below offset    (positive to have chute placed above, negative to to place below)
Dir offset (to make the para chute face forward or backward or any diriction in between)
                
Example:

_refobj = _car
_chute = "animatepara" camcreate [0,0,0]
_offLR = -10
_offFB = -2
_offAB = 5
_diroff = 180
_angoff = 10
_minang = 15
_maxang = 90

_chuteinfo = [_refobj,_chute,_offLR,_offFB,_offAB, _diroff, _minang, _maxang] call Parachute

This will put the _chute 10 meters to the left of the _car, 2 meters behind the _car
and 5 meters above the _car, facing the direction opposite (180 deg.) to the
car's motion and offset +10 degrees from the calculated tilt, but with a tilt no less than 15 degrees
and no more than 90 degrees.

The _chuteinfo will be an array for the _chute position in [x, y, z] format,
the direction of the chute and the phase of the chute.

Initialize this function by putting this in your init.sqs:
Parachute = preprocessFile "Parachute.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_Refpos","_x","_y","_z","_Refdir","_offFB","_offLR","_offAB","_leadX","_leadY","_mdir","_spd","_diroff","_maxang", "_SLref","_alt1","_alt2"];
private ["_leewX","_leewY","_pos","_refobj","_chute","_vel","_xvel","_yvel","_zvel","_hvel","_ang","_phase","_minang","_angoff","_TPref","_altdif"];

_refobj = _this select 0;
_chute = _this select 1;
_offLR = _this select 2;
_offFB = _this select 3;
_offAB = _this select 4;
_diroff = _this select 5;
_angoff = _this select 6;
_minang = _this select 7;
_maxang = _this select 8;

_vel = Velocity _chute;

_xvel = _vel select 0;
_yvel = _vel select 1;
_zvel = _vel select 2;

// find object speed and movement direction from velocity vectors

_hvel = sqrt(_xvel^2 + _yvel^2);

// find movement direction of object (movement direction is not necessarily the "getDir" value)

if (_hvel != 0) then {_mdir = _xvel atan2 _yvel} else {_mdir = getDir _refobj};
_mdir = _mdir + _diroff;
if (_mdir > 360) then { _mdir = _mdir - 360 };
if (_mdir < 0) then { _mdir = _mdir + 360 };

// determine chute lean back angle and animation phase from velocity info

_spd = sqrt(_zvel^2 + _hvel^2);
if (abs _spd > 0) then {_ang = asin((abs _zvel)/_spd)} else {_ang = 0};
_ang = _ang + _angoff;
if (_ang < _minang) then {_ang = _minang};
if (_ang > _maxang) then {_ang = _maxang};
_phase = abs (_ang/90)/2;

_SLref = "emptyDetector" createVehicle [0,0,0];
_TPref = "logic" createVehicle [0,0,0];

_Refdir = getDir _refobj;
_Refpos = getPos _refobj;

_x = _Refpos select 0;
_y = _Refpos select 1;
_SLref setPos [_x, _y];
_TPref setPos [_x, _y, 0];
_alt1 = _TPref distance _SLref;

// Setup _chute position relative to _refobj

_leadX = (_offFB * Sin _Refdir);
_leadY = (_offFB * Cos _Refdir);
_leewX = (_offLR * Sin (_Refdir + 90));
_leewY = (_offLR * Cos (_Refdir + 90));

_SLref setPos [(_leadX + _leewX + _x),(_leadY + _leewY + _y)];
_TPref setPos [(_leadX + _leewX + _x),(_leadY + _leewY + _y), 0];
_alt2 = _TPref distance _SLref;
_altdif = _alt1 - _alt2;
_offAB = _offAB + _altdif;
_z = (_Refpos select 2) + _offAB;

deleteVehicle _SLref;
deleteVehicle _TPref;

_pos = [(_leadX + _leewX + _x),(_leadY + _leewY + _y),_z];
_chute setPos _pos;
_chute setDir _mdir;
_chute animate ["slide", _phase];
[_pos, _mdir, _phase]