/*---------------------------------------------------------------
PosDis function by Raptorsaurus

Returns the 3D distance between two positions, the over the ground
distance between two positions and the altitude difference between
the two positions.  See instructions after code.
---------------------------------------------------------------*/

// declare private variables
private ["_Pos1","_Pos2","_x1","_y1","_z1","_x2","_y2","_z2","_Hdis","_Dalt","_Dis"];

_Pos1 = _this select 0;
_Pos2 = _this select 1;

//make sure the positions are three element, if not, add a zero element

if (count _Pos1 < 3) then {_Pos1 = _Pos1 + [0]};
if (count _Pos2 < 3) then {_Pos2 = _Pos2 + [0]};

//get x,y,z coordinates of positions

_x1 = _Pos1 select 0;
_y1 = _Pos1 select 1;
_z1 = _Pos1 select 2;

_x2 = _Pos2 select 0;
_y2 = _Pos2 select 1;
_z2 = _Pos2 select 2;

// get horizontal distance (_Hdis)

_Hdis = sqrt((_x1-_x2)^2 + (_y1-_y2)^2);

// get delta altitude

_Dalt = Abs (_z1 - _z2);

// get 3D distance

_Dis = sqrt((_Hdis^2) + (_Dalt^2));

[_Dis,_Hdis,_Dalt]

/*---------------------------------------------------------------
Usage instructions:

Pass info to the function in the following format:

_DisArray = [_pos1, _pos2] call PosDis

or

_DisArray = [[_x1,_y1,_z1],[_x2,_y2,_z2]] call PosDis

_DisArry will contain:

_Dis = _DisArray select 0   (The total distance in space [3D distance])
_Hdis = _DisArray select 1  (The distance over ground [horizontal distance])
_Dalt = _DisArray select 2  (The Altitude difference between the positions)

Initialize this function by putting this in your init.sqs:

PosDis = preprocessFile "PosDis.sqf"
---------------------------------------------------------------*/