/*---------------------------------------------------------------
RandChar function by Raptorsaurus

This function returns a random character of the roman alphabet (English version
thereof) in upper or lower case within a specified range.  It will also randomly
generate vowels only, if requested.  Upper or lower case can also be specified

Examples

Eg. 1:
_randchar = [_low, _high, _vow, _Ucase] call RandChar

The _low is the lowest letter range and _high is the highest letter range
(single character string values).  The _vow is a boolean.  If _vow is true then
only vowels will be generated (including "y" if it is in specified range).  The
_Ucase is also boolean, if true then the returned character will be upper case if.
false the returned character will be lower case.

Eg. 2:
_randchar = ["A","Y",true,true] call RandChar

This will return an upper case random vowel including "Y".

Eg. 3:
_randchar = ["A","Z",false,false] call Randchar

This will return a lower case random character from the entire alphabet.

Initialize this function by putting this in your init.sqs:
RandChar = preprocessFile "RandChar.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_low","_high","_vow","_Ucase","_char1","_upper","_lower","_vowlower"];
private ["_vowupper","_boolcheck","_lownum","_highnum","_alpha"];
private ["_alphacnt","_cnt","_num","_alphacheck","_char2"];

_low = _this select 0;
_high = _this select 1;
_vow = _this select 2;
_Ucase = _this select 3;

// set up alphabet arrays and valid value check arrays

_alpha = [];
_lower = ["a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z"];
_upper = ["A","B","C","D","E","F","G","H","I","J","K","L","M","N","O","P","Q","R","S","T","U","V","W","X","Y","Z"];
_vowlower = ["a","e","i","o","u","y"];
_vowupper = ["A","E","I","O","U","Y"];
_boolcheck = [true,false];

// make sure _vow and _Ucase are valid values, if not set them to default values

if (!(_vow in _boolcheck)) then {_vow = nill;_vow = false};
if (!(_Ucase in _boolcheck)) then {_Ucase = nill;_Ucase = true};

// determine which array to use

if (_vow && _Ucase) then {_alpha = _vowupper ; _alphacheck = _vowlower};
if (_vow && !_Ucase) then {_alpha = _vowlower ; _alphacheck = _vowupper};
if (!_vow && _Ucase) then {_alpha = _upper ; _alphacheck = _lower};
if (!_vow && !_Ucase) then {_alpha = _lower ; _alphacheck = _upper};

// make sure _low and _high are valid single character strings, otherwise set them to default values

_alphacnt = count _alpha;

if (!(_low in _alpha) && !(_low in _alphacheck)) then {_low = nil;_low = _alpha select 0};
if (!(_high in _alpha) && !(_high in _alphacheck)) then {_high = nil;_high = _alpha select (_alphacnt - 1)};

// get numerical values for _low and _high (according to alphabet sequence in _alpha)

_cnt = 0;

while {_cnt < _alphacnt} Do
   {
   _char1 = _alpha select _cnt;
   _char2 = _alphacheck select _cnt;
   if (_char1 == _low || _char2 == _low) then {_lownum = _cnt};
   if (_char1 == _high || _char2 == _high) then {_highnum = _cnt};
   _cnt = _cnt + 1;
   };

// make random integer in range of _lownum to _highnum

_num = ((random 1) * (1 + _highnum - _lownum)) + _lownum;
_num = _num - (_num % 1);

// now return the letter in the array represented by that number

_alpha select _num