/*---------------------------------------------------------------
RandNum function by Raptorsaurus
ver. 1.1

This function returns a random number within a speicified range and rounded to
a specified precision.

ver 1.1, (11/3/05):
	Now compensates for high/low limit values having lower chance of being
	picked due to effects of rounding.       

Examples

Eg. 1:
_randnum = [_low, _high, .5] call RandNum

This will return a random number in the range of _low to _high and rounded to
the nearest 0.5.

Eg. 2:
_randnum = [-10,50,1] call RandNum

This will return a random number in the range -10 to 50 and rounded to the
nearest whole number (integer).

Eg. 3:
_randnum = [10,100000,20] call RandNum

This will return a random number in the range 10 to 100000 rounded to the
nearest value evenly divisible by 20.

Initialize this function by putting this in your init.sqs:
RandNum = preprocessFile "RandNum.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_low","_high","_rnd","_num","_sign"];

_low = _this select 0;
_high = _this select 1;
_rnd = _this select 2;

// Just in case the low and high are reversed

if (_low > _high) then {_low = _this select 1; _high = _this select 0};

// make random number in requested range (allows negative numbers & compensates for rounding factor causing high and low values from having lower chance)

_num = (random ((_high + (_rnd/2)) - (_low - (_rnd/2))) ) + (_low - (_rnd/2));
_sign = 1;
if (_num < 0) then {_sign = -1};
_num = abs _num;

// Round _num to requested value then convert it back to it original _sign

((_num + (_rnd/2)) - ((_num + (_rnd/2)) % _rnd)) * _sign