/*---------------------------------------------------------------
RelVel function by Raptorsaurus

Returns the  velocity vectors of a moving object relative to the position
and direction of that object. So, if a plane or missile is flying the x component
will be the velocity of the plane's "slip" (sideways motion), the y component will be the planes
forward horizontal velocity and the z will be the vertical velocity. If a car is driving and take
a wild turn and skids sideways, this function will yeild the sideways skid speed.

Call this funciton by passing the moving object as the parameter.
Example:
_Rvel = [_obj] call RelVel

_sidespeed = _Rvel select 0
_forwardspeed = _Rvel select 1
_verticalspeed = _Rvel select 2

Initialize this function by putting this in your mission "init.sqs" or at the start
of the first script in a mission that uses this function:

RelVel = preprocessFile "RelVel.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_obj","_x","_y","_z","_H", "_dir"];

_obj = _this select 0;

// get the rectangular velocity vector components

_x = (velocity _obj) select 0;
_y = (velocity _obj) select 1;
_z = (velocity _obj) select 2;
_dir = getDir _obj;

// get the horizontal magnitude and relative x and y velocity vectors

_H = sqrt(_x^2 + _y^2);
_x = _H * (sin _dir);
_y = _H * (cos _dir);

// pass the array

[_x, _y, _z]