/*---------------------------------------------------------------
SetBetween function by Raptorsaurus

Sets and object on the imaginary line between a base object and a
target object at a given distance from the base object and vertically
offset by a given amount. Also returns the position of the set object.

_baseobj = mytank
_targobj = evilaircraft
_setobj = invisibleArmor
_dis = (mytank distance evilaircraft) * .9
_zoff = 50
_pos = [_baseobj, _targobj, _setobj, _dis, _zoff] call SetBetween

This will set the invisibleArmor between mytank and evilaircraft at
90% of the distance from mytank to evilaircraft and 50 meters
above the nominal inbetween point.

This can be used to make a tank fire toward the aircraft by use of invisible
targets. Further scripts/functions can help the projectile hit the aircraft.
For example, the intercept.sqf function also by Raptorsaurus.

Initialize this function by putting this in your init.sqs:
SetBetween = preprocessFile "SetBetween.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_Robj","_Tobj","_Sobj","_dirRobj","_bearTobj","_Reldir","_setdis","_zoff"];
private ["_Dis","_SLref","_Ang","_RobjASL","_TobjASL","_Dalt","_deltaY","_deltaX"];
private ["_H","_X","_Y","_Z","_Robjpos","_Gasl","_GLref","_rX","_rY","_rZ","_ASLcomp"];

_Robj = _this select 0;
_Tobj = _this select 1;
_Sobj = _this select 2;
_setdis = _this select 3;
_zoff = _this select 4;

_dirRobj = getDir _Robj;
_Robjpos = getPos _Robj;

_SLref = "emptydetector" camCreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];

// calculate bearing to target

_deltaX = (getPos _Tobj select 0) - (_Robjpos select 0);
_deltaY = (getPos _Tobj select 1) - (_Robjpos select 1);

if (_deltaY == 0) then {_deltaY = .0000001};

_bearTobj = _deltaX atan2 _deltaY;

// set bearing to value that can be used to get relative direction

if (_bearTobj < 0) then {_bearTobj = _bearTobj + 360};

// get relative direction (from _Robj to _Tobj)

_Reldir = _bearTobj - _dirRobj;

// make sure it is in 360 degree format

if (_Reldir <= 0) then {_Reldir = _Reldir + 360};
if (_Reldir > 360) then {_Reldir = _Reldir - 360};

//Calculate ASL of _Robj

_SLref setPos [getPos _Robj select 0, getPos _Robj select 1];
_RobjASL = _Robj distance _SLref;

//Calculate ASL of _Tobj

_SLref setPos [getPos _Tobj select 0, getPos _Tobj select 1];
_TobjASL = _Tobj distance _SLref;

// calculate delta altitude

_Dalt = _TobjASL - _RobjASL;

// get distance from _Robj and _Tobj

_Dis = _Robj Distance _Tobj;

// get relative angle to target

if (_Dis == 0) then {_Dis = .000001};
_Ang = Asin (_Dalt/_Dis);

// calculate vertical position offset

_rZ = _setdis * Sin _Ang;

// calculate horizontal distance component

_H = _setdis * Cos _Ang;

// calculate relative offsets in horizontal plane

_rX = _H * Sin _reldir;
_rY = _H * Cos _reldir;

// calculate absolute position components in horizontal plane

_X = (_Robjpos select 0) + (_rY * Sin _dirRobj) + (_rX * Sin (_dirRobj + 90));
_Y = (_Robjpos select 1) + (_rY * Cos _dirRobj) + (_rX * Cos (_dirRobj + 90));

//Find Sea Level Alt of the ground at the x,y posistion and compensation value for object _ASL

_GLref setPos [_X, _Y, 0];
_SLref setPos [_X, _Y];
_Gasl = _GLref distance _SLref;
_ASLcomp = _RobjASL - _Gasl;
_Z = _ASLcomp + _rZ + _zoff;

deleteVehicle _GLref;
deleteVehicle _SLref;

if (_Z < 0) then {_Z = 0};

_Sobj setPos [_X,_Y,_Z];

// absolute position values

[_X,_Y,_Z]