/*---------------------------------------------------------------
SideArm function by Raptorsaurus
v. 1.0, 8/18/05

Returns an array containing the name of a units sidearm (handgun) and the magazine name
for that weapon.  Optionally, one can also use this function to switch the unit's present sidearm
for a new one or remove his sidearm (if null string is used for the sidearm name).

The required info passed to this function is:

- Unit name
- Name of sidearm to add (optional)
- Name of sidearm magazine to add (optional)

Example 1:

_sidearminfo = [_myguy] call SideArm

_sidearm = _sidearminfo select 0   (this will be the name of the sidearm carried by _myguy, if he has none it will be null value)
_sidearmMag = _sidearminfo select 1 (this will be the name of the sidearm magazine carried by _myguy, if he has none it will be null value)

Example 2:

_oldsidearm = [_myguy, "glockS", "glockSmag"] call SideArm

This will switch the _myguy's sidearm to a "glockS" and switch his magazines to "glockSmag".  If you are curious as to what the previous
sidearm was, that information and the old magazine name will be in the array _oldsidearm.

Initialize this function by putting this in your init.sqs:
SideArm = preprocessFile "SideArm.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_man","_sidearm","_sidearmmag","_hg","_hgmag","_wps","_pwp","_swp","_mags", "_testwps"];

_man = _this select 0;

_hg = "";
_hgmag = "";
_wps = weapons _man;
_pwp = primaryWeapon _man;
_swp = secondaryWeapon _man;

_mags = magazines _man;
_testwps = [_pwp, _swp, "NVGoggles", "Binocular"];

// find the handgun (if any) among the _man's weapons

_hg = (_wps - _testwps) select 0;
if ( _hg != "" ) then { _hgmag = (_mags select ((count _mags) - 1)) };

// if the array parameters include a new sidearm and magazine type, then remove the old sidearm and add the new one in its place
// if the new sidearm or magazine is null then nothing is added (the old sidearm is removed and nothing is added to take its place).
	
If ( count _this > 2 ) then
{
	_sidearm = _this select 1;
	_sidearmmag = _this select 2;
	if ( _hg != "" ) then
	   {
	      _man removemagazines (_mags select ((count _mags) - 1));
	      _man removeweapon _hg;
	   };
	if ( format ["%1", _sidearmmag] != "<null>" && format ["%1", _sidearm] != "<null>" && _sidearmmag != "" && _sidearm != "" ) then
	   {
	      _man addMagazine  _sidearmmag;
	      _man addMagazine  _sidearmmag; 
	      _man addMagazine  _sidearmmag; 
	      _man addMagazine  _sidearmmag;
	      _man addWeapon  _sidearm;
	   };
};

// return the original sidearm and sidearm magazine names
[_hg, _hgmag]