/*-----------------------------------------------------------
StrComp function by Raptorsaurus

Uses a string of characters to simulate a linear pointer compass

The first parameter needed is the direction (compass heading).
The second parameter is the precision for the digital reading.
The third parameter is the number of "tick" marks to show on either
side of the center pointer.  The maximum number is 36.

The returned value will be a string that will indicate the direction.

Eg.

_dir = 325.35689
_prc = .01
_ticks = 16

_str = [_dir,_prc,_ticks] call StrComp

_str will contain the following:

NW--------N------<325.36>-NE--------E-----

Initialize this function by putting this in your init.sqs:
StrComp = preprocessFile "StrComp.sqf"
------------------------------------------------------------*/

private ["_dir","_prc","_ind","_comp","_compcnt","_pnt","_pntL","_pntR","_pick"];
private ["_maxelmt","_indst","_st","_cnt","_tks"];

_dir = _this select 0;
_prc = _this select 1;
_tks = _this select 2;

if (_tks > 36) then {_tks = 36};

_comp = ["-","-","-","-","-","-","-","-","NE","-","-","-","-","-","-","-","-","E","-","-","-","-","-","-","-","-","SE","-","-","-","-","-","-","-","-","S","-","-","-","-","-","-","-","-","SW","-","-","-","-","-","-","-","-","W","-","-","-","-","-","-","-","-","NW","-","-","-","-","-","-","-","-","N"];
_compcnt = count _comp;
_maxelmt = _compcnt - 1;

// Round _dir to the nearest 5 degrees for indicator position

_ind = (_dir + (5/2)) - (( _dir + (5/2)) % 5);

if (_ind == 0) then {_ind = 360};

// Round _dir to the requested precision

_dir = (_dir + (_prc/2)) - (( _dir + (_prc/2)) % _prc);

// Find the segement of _comp that indicates the direction

_pnt = (_ind/5) - 1;
_pntL = _pnt - _tks;
_pntR = _pnt + _tks;
_cnt = _pntL;
_indst = "";

While {_cnt <= _pntR}
Do
  {
   _pick = _cnt;
   if (_pick < 0) then {_pick = _compcnt + _pick};
   if (_pick > _maxelmt) then {_pick = _pick - _compcnt};
   _st = _comp select _pick;
   if (_cnt == _pnt) then {_st = format ["<%1>",_dir]};
   _indst = _indst + _st;
   _cnt = _cnt + 1;
  };
_indst