/*-----------------------------------------------------------
TmAsStr function by Raptorsaurus
(based on timetostring function -=- by snYpir)

Converts decimal hours into hours:minutes:seconds.decimal seconds format
This version can be used for either a timer or 24 hour digital clock

The second parameter is the desired output format.
It can be:

"SS"          - Seconds only
"SS.00"       - Seconds.decimal seconds
"MM:SS"       - Minute:Seconds
"MM:SS.00"    - Minute:Seconds.decimal seconds
"HH:MM:SS"    - Hours:Minutes:Seconds
"HH:MM:SS.00" - Hours:Minutes:Seconds.decimal seconds
"ARRAY"       - [Hour,Minute,Seconds,decimal seconds]

If the second parameter is not provided, it defaults to
"HH:MM:SS.00"

Input must be decimal time in hours and the format must be in all CAPITAL LETTERS.

Eg.

_dechours = 13.567
_format = "HH:MM:SS"

_displaytime = [_dechours,_format] call TmAsStr

The value of _displaytime will be:  "13:34:01"

If the _format was "HH:MM:SS.00" then the value of _displaytime would be:  13:34:01.20

Initialize this function by putting this in your init.sqs:
TmAsStr = preprocessFile "TmAsStr.sqf"
------------------------------------------------------------*/

private ["_num", "_format", "_min", "_hour", "_sec", "_dsec", "_return"];

_num = _this select 0;

if (count _this > 1) then { _format = _this select 1 } else {_format = "HH:MM:SS.00"};

// In case user used oo or OO instead of 00 for decimal seconds

if (_format == "HH:MM:SS.oo") then {_format == "HH:MM:SS.00"};
if (_format == "MM:SS.oo") then {_format == "MM:SS.00"};
if (_format == "SS.oo") then {_format == "SS.00"};
if (_format == "HH:MM:SS.OO") then {_format == "HH:MM:SS.00"};
if (_format == "MM:SS.OO") then {_format == "MM:SS.00"};
if (_format == "SS.OO") then {_format == "SS.00"};

// Separate the decimal and whole parts, the whole part will be hours

_hour = _num - (_num % 1);
_num = abs (_num - _hour);

// Now make the remaining number into minutes and then do the same, but for minutes

_num = _num * 60;
_min = _num - (_num % 1);
_num = abs (_num - _min);

// Now do seconds, the remainder is decimal seconds

_num = _num * 60;
_sec = _num - (_num % 1);
_dsec = abs (_num - _sec);

// Round the decimal seconds to two places (100ths)

_dsec = (_dsec + (.01/2)) - (( _dsec + (.01/2)) % .01);

if (_format == "SS.00" || _format == "SS") then {_sec = _sec + (_hour * 3600) + (_min * 60)};
if (_format == "MM:SS.00" || _format == "MM:SS") then {_min = _min + (_hour * 60)};

// Depending on desired ouput format, either round _sec + _dsec to nearest whole
// or add _sec and _dsec and leave decimal value

if (_format == "HH:MM:SS.00" || _format == "MM:SS.00" || _format == "SS.00")
   then { _sec = _sec + _dsec}
   else
   {
    _sec = _sec + _dsec;
    _sec = (_sec + (1/2)) - (( _dsec + (1/2)) % 1);
   };

// Output formating

if (_hour <= 9) then {_hour = format["0%1",_hour]} else {_hour = format["%1",_hour]};

if (_min <= 9) then {_min = format["0%1",_min]} else {_min = format["%1",_min]};

if (_sec <= 9) then {_sec = format["0%1",_sec]} else {_sec = format["%1",_sec]};

if (_format == "SS" || _format == "SS.00") then {_return = format["%1",_sec]};

if (_format == "MM:SS" || _format == "MM:SS.00") then {_return = format["%1:%2",_min,_sec]};

if (_format == "HH:MM:SS" || _format == "HH:MM:SS.00") then {_return = format["%1:%2:%3",_hour,_min,_sec]};

if (_format == "ARRAY") then {_return = [_hour,_min,_sec,_dsec]};

_return