/*---------------------------------------------------------------
TomTrkDir function by Raptorsaurus

Sets the Marker Type most closely corresponding to the direction of the
vehicle being tracked.  If the vehicle is found to be destroyed then the marker
type is set to "empty".

This function requires the addon: Tommarkers by Wizzywig.

This function was specially created for use with the Tomahawk addon by
Wizzywig & Raptorsaurus.

Pass the object and marker name to the function along with the desired color:

[_obj,_mrk,_col] call TomTrkDir

or

[_craft,"tomahawk","colorgreen"] call TomTrkDir

The function will then set the marker type and position accordingly.

Initialize this function by putting this in your init.sqs:
TomTrkDir = preprocessFile "TomTrkDir.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_obj","_posObj","_dirObj","_mkType","_mrk","_dir","_col"];
private ["_vel","_x","_y","_z","_spd"];

_obj = _this select 0;
_mrk = _this select 1;
_col = _this select 2;

// Get position and velocity of unit

_posObj = getPos _obj;
_vel = Velocity _obj;
_spd = speed _obj;

// get the rectangular velocity vector components

_x = _vel select 0;
_y = _vel select 1;
_z = _vel select 2;

// find compass direction (movement direction is not necessarily the "getDir" value)

if (_spd > 0 && _x != 0 && _y != 0) then {_dirObj = _x atan2 _y} else {_dirObj = getDir _obj};
if (_dirObj < 0) then { _dirObj = _dirObj + 360 };

// Round compass heading to nearest 10 degree increment

_dir = (_dirObj + 5) - ((_dirObj + 5) % 10);
if (_dir == 0) then {_dir = 360};

// Create string value for marker type and set marker in tracking position

_mkType = format ["Tom%1",_dir];
_mrk setMarkerPos _posObj;
_mrk setMarkerType _mkType;
_mrk setMarkerColor _col;

// If unit is dead or non-existent set markertype to "empty"

If (!alive _obj or isnull _obj) then {_mrk setMarkerType "empty"};
