/*---------------------------------------------------------------
TypeInTraj function by Raptorsaurus

Returns arrays of all targest of a given type along the trajectory of a projectile. And which target is the closest
to the trajectory path.

The required info passed to this function is:

- The projectile
- The class type of potential targets (ie. "man", "tank", "plane")
- distance (the distance ahead of the projectile to check)
- increment (the minimum distance increments to check between the projectile and the furthest distance)
- (OPTIONAL) excluded types array (array of types of targets to not include - like if you want skip invisible targets for instance)

Example:

_targs = [_missile, "man", 2000, 10, ["soldierWB", "soldierGB", "civilian"]] call TypeInTraj

Targets of the type "soldierWB", "soldierGB", "civilian"]\ will be excluded as potential targets.

_targs is a two element array.  The first element is an array of all the "man" targets along the trajectory path.
The second element is the single "man" target that is closest to the trajectory path.

_allTargs = _targs select 0:
This is an array of all the man class targets nearest to the path of the missile up to 2000 meters away (excluding those
specified in the exclude array ["soldierWB", "soldierGB", "civilian"]). The check increments will be every 10 meters.

_BestTarg = _targs select 1:
This is the "man" target that is nearest to the missiles trajectory (the target that missile is most likey to hit.)

Initialize this function by putting this in your init.sqs:
TypeInTraj = preprocessFile "TypeInTraj.sqf"
---------------------------------------------------------------*/
private ["_proj", "_dis", "_dir", "_inc", "_obj", "_Pvel", "_XvelP", "_YvelP", "_ZvelP", "_Pang", "_Hvel", "_Pspd", "_Tdis","_exca"];
private ["_discnt","_X","_Y","_Z", "_H", "_Ppos", "_objA", "_SLref", "_GLref", "_ASL", "_type", "_disT", "_objN", "_exct","_ctype"];
_proj = _this select 0;
_type = _this select 1;
_dis = _this select 2;
_inc = _this select 3;
_exct = [];
if (count _this > 4) then
	{
	_exct = _this select 4;
	_exca = [];
	{_exca = _exca + [(_x createVehicle [0,0,0])]} forEach _exct;
	_exct = [];
	{_exct = _exct + [(typeOf _x)]} forEach _exca;
	{deleteVehicle _x} forEach _exca;
	};
_exct = _exct + ["SmokeSource","Track","Mark","ObjectDestructed","Explosion","Crater","CraterOnVehicle","Slop","Smoke","DynamicSound"];
_SLref = "emptydetector" createVehicle [0,0,0];
_GLref = "logic" createVehicle [0,0,0];
_objA = [_proj];
_disT = 999999;
_objN = objNull;

// get the velocity & pos

_Pvel = Velocity _proj;
_Ppos = getPos _proj;
_SLref setPos [_Ppos select 0, _Ppos select 1];
_ASL = _proj distance _SLref;

// get the rectangular velocity vector components

_XvelP = (_Pvel select 0);
_YvelP = (_Pvel select 1);
_ZvelP = (_Pvel select 2);

// find projectile speed and movement direction from velocity vectors
// (this is more reliable than using "getDir" and "Speed" commands)

_Hvel = sqrt(_XvelP^2 + _YvelP^2);
If (_Hvel == 0) then
{
  If (_ZvelP > 0) then {_Pang = 90};
  If (_ZvelP < 0) then {_Pang = -90};
  If (_ZvelP == 0) then {_Pang = 0};
};
If (_Hvel != 0)
then
{
  _Pang = Atan (_ZvelP/_Hvel);
  _Pspd = _Hvel / Cos _Pang;
}
Else
{
  _Pspd = abs _ZvelP;
};

// find compass direction of projectile (movement direction is not necessarily the "getDir" value)

if (_Pspd > 0 && _YvelP != 0) then {_dir = _XvelP atan2 _YvelP} else {_dir = getDir _proj};
if (_dir < 0) then { _dir = _dir + 360 };

// find objects along trajectory path of _proj

_discnt = _inc;
While {_discnt <= _dis} Do
   	{
	_Z = _discnt * Sin _Pang;
	_H = _discnt * Cos _Pang;
	_X = (_Ppos select 0) + (_H * Sin _dir);
	_Y = (_Ppos select 1) + (_H * Cos _dir);
	_GLref setPos [_X, _Y, 0];
	_SLref setPos [_X, _Y];
	_Z = _Z + (_ASL - (_GLref distance _SLref));
	_GLref setPos [0,0,0];
	_SLref setPos [0,0];
	if (_Z < 0) then {_Z = 0};
	_obj = nearestObject [_X, _Y, _Z];
	_ctype = false;
	{if (_x countType [_obj] == 1) then {_ctype = true}} forEach _exct;
	if (! (_obj in _objA) && _type countType [_obj] == 1 && ! _ctype) then
		{
		_objA = _objA + [_obj];
		_Z = (_proj distance _obj) * Sin _Pang;
		_H = (_proj distance _obj) * Cos _Pang;
		_X = (_Ppos select 0) + (_H * Sin _dir);
		_Y = (_Ppos select 1) + (_H * Cos _dir);
		_GLref setPos [_X, _Y, 0];
		_SLref setPos [_X, _Y];
		_Z = _Z + (_ASL - (_GLref distance _SLref));
		_GLref setPos getPos _obj;
		_Zoff = _GLref distance _obj;
		if ("man" countType [_obj] == 1 && alive _obj) then {_Zoff = _Zoff + .5}; 
		_GLref setPos [_X, _Y, (_Z - _Zoff)];
		if (_GLref distance _obj < _disT) then {_disT = _GLref distance _obj; _objN = _obj;};
		};
	_discnt = _discnt + _inc;
	};
deleteVehicle _GLref;
deleteVehicle _SLref;
[_objA - [_proj], _objN]