/*---------------------------------------------------------------
VelVect function by Raptorsaurus

Returns the Velocity of an object in magnitude and angle relative to
horizontal.

Pass the object to the function:

_Velvect = [_obj] call VelVect

_Vmag = _VelVect select 0
_VAng = _Velvect select 1

Note: _Vmag is the same as speed except it is in m/s

Initialize this function by putting this in your init.sqs:
VelVect = preprocessFile "VelVect.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_vel","_x","_y","_z","_Ang","_Hvel","_Mag"];

_vel = Velocity (_this select 0);

// get the rectangular velocity vector components

_x = _vel select 0;
_y = _vel select 1;
_z = _vel select 2;

// convert to magnitued & angle format

_Hvel = sqrt(_x^2 + _y^2);

If (_Hvel == 0) then
{
  If (_z > 0) then {_Ang = 90};
  If (_z < 0) then {_Ang = -90};
  If (_z == 0) then {_Ang = 0};
};
If (_Hvel != 0)
then
{
  _Ang = Atan (_z/_Hvel);
  _Mag = _Hvel / Cos _Ang;
}
Else
{
  _Mag = abs _z;
};

// create velocity vector as array
[_Mag,_Ang]
