/*---------------------------------------------------------------
flyInASL function by Raptorsaurus (Ver. 1.0)

This function helps make aircraft fly at a given altituted referenced to sea level.
It determines the flyInHeight by looking at the above sea level altitude of the
terrain out in front of the craft.  The adjusted flyInHeight is adjusted for the desired
ASL.  If used in a loop that constantly updates according the the terrain in front of
the craft, the aircraft can be made to fly at a constance ASL (Above Sea Level)
altitude.  The function returns an array of the compensated flyInHeight value, the ASL
of the ground at the lookahead point and the climb/dive angle required to get the craft
to the desired altitude.  Since the function gives the craft the flyInHeight command,
the returned information is only needed for feedback or for the needed info to force
the craft to the desired altitude using means other than the flyInHeight command.

Pass info to the function in the following format: 

_ASLinfo = [_craft,_nomASL,_lookaheadDis,_AGLlimit] call flyInASL 

_craft is the name of the aircraft, _nomASL is the nominal altitude Above Sea
Level, _lookaheadDis is the distance to look ahead of the aircraft and _AGLlimit
is the minimum Above Ground Level altitude (so that the craft does not fly into a
mountain or hill that rises above the _nomASL).

_ASLinfo will be an array with the following values:

[flyInHeight, GASL, Angle]

The flyInHeight is the altituted to which the craft is being told to fly. The GASL is the sea level altitude
of the ground at the _lookaheadDis in front of the craft.  Angle is the elevation angle the craft would
have to fly at in order to reach the desired ASL by the time it reaches the _lookaheadDis.

Initialize this function by putting this in your init.sqs: 
flyInASL = preprocessFile "flyInASL.sqf"
---------------------------------------------------------------*/
// declare private variables
private ["_craft","_dir","_GLref","_GLrefASL","_AGL","_ASL", "_rDis","_SLref", "_AGLlim", "_Hvel", "_crASL", "_ang"];

// get needed values

_craft = _this select 0;
_ASL = _this select 1;
_rDis = _this select 2;
_AGLlim = _this select 3;

if (_rDis < 1) then {_rDis = 1};

// find movement direction of _craft (movement direction is not necessarily the "getDir" value)
_Hvel = sqrt((velocity _craft select 0)^2 + (velocity _craft select 1)^2);
if (_Hvel != 0) then {_dir = (velocity _craft select 0) atan2 (velocity _craft select 0)} else {_dir = getDir _obj};
if (_dir < 0) then { _dir = _dir + 360 };

// create Sea level reference and Ground level references

_SLref = "emptyDetector" createVehicle [0, 0, 0];
_GLref = "logic" createVehicle [0,0,0];

//Find _craft ASL

_SLref setPos [getPos _craft select 0, getPos _craft select 1];
_crASL = _craft distance _SLref;

//Find ASL at _rDis in front of craft

_GLref setPos [((getPos _craft select 0) + (_rDis * Sin _dir)),((getPos _craft select 1) + (_rDis * Cos _dir)),0];
_SLref setPos [getPos _GLref select 0, getPos _GLref select 1];
_GLrefASL = _GLref distance _SLref;

//Calculate the _AGL needed to get the craft to _ASL at the position in front of the craft

_AGL = _ASL - _GLrefASL;
if (_AGL < _AGLlim) then {_ASL = _ASL + (_AGLlim - _AGL); _AGL = _AGLlim};
_craft flyInHeight _AGL;

//Calculate the climb/dive angle needed for the craft to reach the desired ASL at _rDis in front of _craft.

_ang = Atan ((_ASL - _crASL) / _rDis);

deleteVehicle _GLref;
deleteVehicle _SLref;

[_AGL,_GLrefASL, _ang]