/*---------------------------------------------------------------
groundSlope function by Raptorsaurus (v. 1.02, July 06, 2010)

v. 1.02 : Now returns the greatest slope in the slope direction

Returns the average slope of the ground in the direction of greatest slope
within a specified circular area around a reference position or object, the
direction of the upward slope and the maximum slope from the center of
the check area to the edge.

Pass info to the function in the following format: 

_slope = [pos, radius, arc_inc] call groundSlope
or
_slope = [[obj], radius, arc_inc] call groundSlope

The pos or [obj] defines the center of the area of ground for which the slope will be measured.
The radius defines the size of the circular area of terrain to be measured.
The arc_inc is the directional increment for measuring the ground slope in directions from 0 to 360.

Example: 

_pos = getPos player
_Slope = [_pos, 20, 10] call groundSlope

This will return a 2 dim array containing the slope and the direction of greatest average slope.  The area to be checked will be a
20 m circle centered at the [x,y] position of the player.  The slope direction will be checked in 10 deg. increments.

_slope select 0 is the average ground slope in the direction of the greatest slope in the 20 m circle of land
		centered at _pos 
_slope select 1 is the direction in which the slope is the greatest for that area of terrain.
_slope select 2 is the greatest slope from the _pos to the check radius edge.

Initialize this function by putting this in your init.sqs: 
groundSlope = preprocessFile "groundSlope.sqf"
---------------------------------------------------------------*/
// declare private variables
private ["_input","_pos","_rad","_dirinc","_X","_Y", "_SLref", "_GLref", "_refASL"];
private ["_recdir", "_recang", "_dir", "_ASL", "_deltaAlt", "_ang", "_tAng", "_cnt"];

// get needed values

_input = _this select 0;
_rad = _this select 1;
_dirinc = _this select 2;

if (count _input == 1) then {_pos = [(getPos (_input select 0)) select 0, (getPos (_input select 0)) select 1]};
if (count _input > 1) then {_pos = [_input select 0, _input select 1]};
_X = _pos select 0;
_Y = _pos select 1;

_SLref = "emptyDetector" createVehicle [0,0,0];
_GLref = "logic" createVehicle [0,0,0];

//Calculate refASL of the terrain at the object location 

_SLref setPos [_X, _Y];
_GLref setPos [_X, _Y, 0];
_refASL = _GLref distance _SLref;

// find the direction with the greatest slope.

_recdir = 0;
_recang = 0;
_dir = 0;

While {_dir < 360}
Do
{
	//place the range _GLref and _SLref and calculate the angle to that point

	_GLref setPos [(_X + (_rad * Sin _dir)),(_Y + (_rad * Cos _dir)),0];
	_SLref setPos [(_X + (_rad * Sin _dir)),(_Y + (_rad * Cos _dir))];
	_ASL = _GLref distance _SLref;
	_deltaAlt = (_ASL) - (_refASL);
	_ang = (Atan (_deltaAlt/_rad));
	if (abs _ang > abs _recang)
	then 
	{
		_recang = _ang;
		_recdir = _dir;
		if (_recang < 0)
		then 
		{
			_recdir = _dir + 180;
			if (_recdir > 360) then {_recdir = _recdir - 360};
		};
	};
	_dir = _dir + _dirinc;	
};

// find the average slope in the direction of the greatest slope.	

_tAng = 0;
_cnt = _rad / 5;

While {_cnt < _rad}
Do
{
	//place the range _GLref and _SLref and calculate the angle to that point
	_GLref setPos [(_X + (_cnt * Sin _recdir)),(_Y + (_cnt * Cos _recdir)),0];
	_SLref setPos [(_X + (_cnt * Sin _recdir)),(_Y + (_cnt * Cos _recdir))];
	_ASL = _GLref distance _SLref;
	_deltaAlt = (_ASL) - (_refASL);
	_ang = Atan (_deltaAlt/_cnt);
	_tAng = _tAng + (Abs _ang);
	//do it again in the opposite direction
	_GLref setPos [(_X + (_cnt * Sin (_recdir + 180))),(_Y + (_cnt * Cos (_recdir + 180))),0];
	_SLref setPos [(_X + (_cnt * Sin (_recdir + 180))),(_Y + (_cnt * Cos (_recdir + 180) ))];
	_ASL = _GLref distance _SLref;
	_deltaAlt = (_ASL) - (_refASL);
	_ang = Atan (_deltaAlt/_cnt);
	_tAng = _tAng + (Abs _ang);
	_cnt = _cnt + (_rad / 5);
};

_avgAng = _tAng / 10;

deleteVehicle _GLref;
deleteVehicle _SLref;

// Return the values

[_avgAng, _recDir, abs _recang]