/*---------------------------------------------------------------
line function by Raptorsaurus

Returns an array of positions along a defined line segment. The segment
can be defined by either two points or a starting point, a distance, a
direction, and an angle.

Required Parameters, start point, end point version:

- Starting position
- Ending position
- Number of points

Required Parameters, start point, distance, direction, angle version

- Starting position
- Distance
- Direction (compass heading)
- Angle (off horizontal [90 is straight up, -90 is straint down])
- Number of points

Example 1 (line defined by start point, end point):

_posArray = [_StartPos, _EndPos, _Num] call line

Example 2 (line defined by start point, distance, direction, angle):

_posArray = [_StartPos,_Dis,_Dir,_Ang, _Num] call line

Initialize this function by putting this in your init.sqs:
line = preprocessFile "line.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_spos","_dis","_dir","_ang","_num","_SLref","_GLref","_inc","_seg","_posArray","_x","_y","_zoff","_z"];
private ["_epos","_deltaX","_deltaY","_sASL","_eASL","_Dalt","_Dref"];

// make reference tools
_SLref = "emptydetector" createVehicle [0,0,0];
_GLref = "logic" createVehicle [0,0,0];
_Dref = "logic" camcreate [0,0,0];

_spos = _this select 0;
//Calculate ASL at _spos
_SLref setPos [_spos select 0, _spos select 1];
_GLref setPos [_spos select 0, _spos select 1, _spos select 2];
_sASL = _SLref distance _GLref;

if (count _this > 3)
	then
	{
	_dis = _this select 1;
	_dir = _this select 2;
	_ang = _this select 3;
	_num = _this select 4;
	}
	else
	{
	_epos = _this select 1;
	_num = _this select 2;
	//Get heading from _spos to _epos
	_deltaX = (_epos select 0) - (_spos select 0);
	_deltaY = (_epos select 1) - (_spos select 1);
	if (_deltaY == 0) then {_deltaY = .0000001};
	_dir = _deltaX atan2 _deltaY;
	if (_dir < 0) then {_dir = _dir + 360};
	//Calculate ASL at _epos
	_SLref setPos [_epos select 0, _epos select 1];
	_GLref setPos [_epos select 0, _epos select 1, _epos select 2];
	_eASL = _SLref distance _GLref;
	// calculate delta altitude
	_Dalt = _eASL - _sASL;
	// get distance from _spos to _epos
	_GLref setPos [_spos select 0, _spos select 1, _spos select 2];
	_Dref setPos [_epos select 0, _epos select 1, _epos select 2];
	_Dis = _GLref Distance _Dref;
	// get relative angle to target
	if (_Dis < abs _Dalt) then {_Dis = abs _Dalt};
	if (_Dis == 0) then {_Dis = .0000001};
	_ang = Asin (_Dalt/_Dis);
	};

//Find array of positions along line

_inc = _dis / (_num - 1);
_seg = _inc;
_posArray = [_spos];

While {_seg <= _dis} Do
	{
	_x = (_spos select 0) + ((_seg * Cos _ang) * Sin _dir);
	_y = (_spos select 1) + ((_seg * Cos _ang) * Cos _dir);
	_zoff = _seg * Sin _ang;
	//Determine _z correcting for _sASL
	_GLref setPos [_x, _y, 0];
	_SLref setPos [_x, _y];
	_z = _zoff + (_sASL - (_GLref distance _SLref));
	_posArray = _posArray + [[_x,_y,_z]];
	_seg = _seg + _inc;
	};

deleteVehicle _GLref;
deleteVehicle _SLref;
deleteVehicle _Dref;

_posArray