/*---------------------------------------------------------------
overLand function by Raptorsaurus (version 1.00, Oct, 2011)

Returns true if an object or position is over/on land, false if object or pos
is over/in water. If a radius and distance greater than 0 is used, the function will return
true if any part of the circular area is over land.

Parameters:

Postition or Object
	Pass the object name in array brackets [objname] or position (3 [x,y,z]
	or  2 [x,y] dim format) to the function.
Radius
	The radius of the area to check surrounding the position or object
Distance
	The distance between check points

Examples:

_land = [[_Plane], 20, 5] call overLand
_land = [(getPos _plane), 5, 1] call overLand
_land = [[124, 1345.10], 0, 0] call overLand

Initialize this function by putting this in your init.sqs:
overLand = preprocessFile "overLand.sqf"
---------------------------------------------------------------*/

private ["_input", "_pos" , "_SLref", "_GLref","_tASL", "_tide", "_land", "_rad", "_inc", "_radcnt", "_dir", "_X", "_Z", "_dis"];
_input = _this select 0;
_rad = abs (_this select 1);
_dis = abs (_this select 2);
if (_dis == 0) then {_dis = 1};
if (count _input == 1) then {_pos = [(getPos (_input select 0)) select 0, (getPos (_input select 0)) select 1]};
if (count _input > 1) then {_pos = [_input select 0, _input select 1]};
_X = _pos select 0;
_Y = _pos select 1;
_land = false;
_SLref = "emptyDetector" camcreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];
_SLref setPos [0,0];
_GLref setPos [0,0,0];
_tide = _GLref distance _SLref;
_inc = 0;
_radcnt = 0;
While {_radcnt <= _rad && ! _land}
Do
{
	if (_radcnt > 0) then {_inc = 360 / ( (360 / Asin (_dis/_radcnt)) - ((360 / Asin (_dis/_radcnt)) % 1) )};
	_dir = 0;
	While {_dir < 360 && ! _land}
	Do
	{
		_pos = [(_X + (_radcnt * Sin _dir)), (_Y + (_radcnt * Cos _dir))];
		_SLref setPos _pos;
		_GLref setPos [_pos select 0, _pos select 1, 0];
		_tASL = _GLref distance _SLref;
		if (abs (_tASL - _tide) >= .01) then {_land = true};
		if (_inc > 0) then {_dir = _dir + _inc} else {_dir = 360};
	};
	_radcnt = _radcnt + _dis;
};
deleteVehicle _SLref;
deleteVehicle _GLref;
_land