/*---------------------------------------------------------------
overObst function by Raptorsaurus, v1.02 July 5, 2010

v1.01:	Optional parameter that lets user specify additional object types to force the function to consider those as obstacles.
	User editable array in function body added so that user can include object types that he wants to force the function to regard as obstacles.
	(This was addeded so that non BIS objects that may not normally work with this function will now work). Please inform Raptorsaurus via
	Personal Message at OFPEC.com of any such objects and the exact object typeName and where he can download the addon that includes
	those objects. This will allow Raptorsaurus to update this function to work with the latest addons.
v1.02:     Now checks for Nogova bridge (>35 m self distance)
	
Returns true if position is on/over an obstacle that can damage a vehicle and false otherwise.
Obstacles include trees, houses, other vehicles, large bushes, and fences.  This function does
not return true if a position is over a forest, for that use the overForest function by Raptorsaurus.
If you encounter objects to which this function does not respond, you can add those objects as the
optional last parameter. Or, if the objects are frequently encountered, you can modify the function
by including that/those object type name(s) to the array _userObjs (see comments below).

The required info passed to this function is:

- Position (either 2D [x,y] or 3D [x,y,z]
- radius of check (the radius of the area to check for obstacles)
- OPTIONAL array of additional object types that this function is not properly finding (this may include non-BIS objects and non-BIS map objects)

Example 1:
_overObst = [getPos chopper, 20] call overObst

If their are any unlandable obstacles (trees, houses, vehicles) within 20 m of the point
directly under the chopper, then _overObst will be true, otherwise it will be false

Example 2:
_overObst = [getPos chopper, 20, ["myNewHouse", "myNewTank"] ] call overObst

This will do the same as example 1, but it will also check for "myNewHouse" and "myNewTank"

Initialize this function by putting this in your init.sqs:
overObst = preprocessFile "overObst.sqf"
---------------------------------------------------------------*/
private ["_refpos", "_rad", "_inc", "_refobj", "_overObst", "_dis", "_safepos","_userObjs"];
private ["_radcnt","_X","_Y","_objA", "_dir", "_obj", "_x2", "_y2", "_Z", "_bad"];

// If you know of objects that this function does not properly find, add those type names to the following array. Be aware that type names are case sensitive.
// Use this format: _userObjs = ["typeName1", "typeName2".....etc.] ; where typeName1and typeName2 are the type names.
_userObjs = [];

_refpos = _this select 0;
_rad = _this select 1;
if (count _this > 2) then {_userObjs = _userObjs + (_this select 2)};

_bad = ["SmokeSource","Track","Mark","ObjectDestructed","Explosion","Crater","CraterOnVehicle","Slop","Smoke","DynamicSound"];

_X = _refpos select 0;
_Y = _refpos select 1;
_Z = 4;

_refobj = "logic" createVehicle [0,0,1000];
_safepos = [0,0,1000];

_overObst = false;

_objA = [];
_inc = 0;
_radcnt = 0;
While {_radcnt <= _rad && ! _overObst}
Do
{
	if (_radcnt > 0) then {_inc = 360 / ( (360 / Asin (5/_radcnt)) - ((360 / Asin (5/_radcnt)) % 1) )};
	_dir = 0;
	While {_dir < 360 && ! _overObst}
	Do
      {
		_obj = nearestObject [(_X + (_radcnt * Sin _dir)), (_Y + (_radcnt * Cos _dir)), _Z];
		if (format ["%1",_obj] != "<NULL-object>" && ! (_obj in _objA) && ! (typeOf _obj in _bad))
		then
		{
			_objA = _objA + [_obj, (typeOf _obj)];
			_x2 = (getPos _obj) select 0;
			_y2 = (getPos _obj) select 1;
			_dis = sqrt((_X - _x2) ^2 + (_Y - _y2) ^2);
			if (_dis <= _rad)
				then
				{
					_refobj setPos (getPos _obj);
					_dis = _refobj distance _obj;
					if ((_dis > 1.14 && _dis < 11) || (_dis > .3 && _dis < .5) || (_dis > .045 && _dis < .075) || _dis > 35 || (typeOf _obj in _userObjs)) then {_overObst = true};
					_refobj setPos _safepos;
				};
		};
		if (_inc > 0) then {_dir = _dir + _inc} else {_dir = 360};
	};
	_radcnt = _radcnt + 5;
};
deleteVehicle _refobj;
_overObst