/*---------------------------------------------------------------
overWater function by Raptorsaurus (version 1.01, Jan. 28, 2006)
v 1.01, 1/28/06 added radius and distance parameters to allow check for water under a circular area.

Returns true if an object or position is over/in water, false if object or pos
is over/on land.  If a radius and distance greater than 0 is used, the function will return
true if any part of the circular area is over water.

Parameters:

Postition or Object
	Pass the object name in array brackets [objname] or position (3 [x,y,z]
	or  2 [x,y] dim format) to the function.
Radius
	The radius of the area to check surrounding the position or object
Distance
	The distance between check points

Examples:

_water = [[_Plane], 20, 5] call overWater
_water = [(getPos _plane), 5, 1] call overWater
_water = [[124, 1345.10], 0, 0] call overWater

Initialize this function by putting this in your init.sqs:
overWater = preprocessFile "overWater.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_input", "_pos" , "_SLref", "_GLref","_tASL", "_tide", "_water", "_rad", "_inc", "_radcnt", "_dir", "_X", "_Z", "_dis"];

_input = _this select 0;
_rad = abs (_this select 1);
_dis = abs (_this select 2);
if (_dis == 0) then {_dis = 1};
if (count _input == 1) then {_pos = [(getPos (_input select 0)) select 0, (getPos (_input select 0)) select 1]};
if (count _input > 1) then {_pos = [_input select 0, _input select 1]};
_X = _pos select 0;
_Y = _pos select 1;
_water = false;

// Put Sea level reference and ground level reference, calculate tidal offset
_SLref = "emptyDetector" camcreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];
_SLref setPos [0,0];
_GLref setPos [0,0,0];
_tide = _GLref distance _SLref;

_inc = 0;
_radcnt = 0;

While {_radcnt <= _rad && ! _water}
Do
{
	if (_radcnt > 0) then {_inc = 360 / ( (360 / Asin (_dis/_radcnt)) - ((360 / Asin (_dis/_radcnt)) % 1) )};
	_dir = 0;
	While {_dir < 360 && ! _water}
	Do
	{
		_pos = [(_X + (_radcnt * Sin _dir)), (_Y + (_radcnt * Cos _dir))];
		_SLref setPos _pos;
		_GLref setPos [_pos select 0, _pos select 1, 0];
		_tASL = _GLref distance _SLref;
		if (abs (_tASL - _tide) < .01) then {_water = true};
		if (_inc > 0) then {_dir = _dir + _inc} else {_dir = 360};
	};
	_radcnt = _radcnt + _dis;
};

deleteVehicle _SLref;
deleteVehicle _GLref;

_water