/*---------------------------------------------------------------
revealInfo function by Raptorsaurus
v. 1.0, 06/20/05

OBSOLETE!!!! Causes too much lag in missions! See knowns.sqf and knowers.sqf

This function passes knowledge of known enemies to freindly units and will return information
about which units know about enemies, the enemies they know about and the degree of knowlege
they have.  The information returned is in the form of two arrays of arrays.  The first array is a list
of 3 element arrays which are in this format:  [knower, mostKnown, knowledge].  This array is in the 
order of knowlege (greatest to least).  The knower is the unit who has knowledge, the mostKnown is the
enemy that he knows most about, and knowledge is how much he knows.  This array list will only be
as long as the number of living friendly units that know about enemies.  The second array is a list of
three element arrays in this format: [known, knownMostby, knowlege].  The known is the unit that is
known by a unit on the opposing side.  The knownMostby is the unit on the opposing side that has the
greatest knowledge of the unit.  The knowledge is the degree of knowledge the opposing unit has.  This 
array list will only be as long as the number of known units.

The required info passed to this function is:

- friendly units (array of those units to whom information on known units will be passed)
- enemy units (array of those enemies of the friendly units)
- minimum knowledge (the minimum level of knowlege required before a unit will be considered "known")
- max range (the distance that the friendly units must be from each other in order to share information.  If you do
  not want information sharing, then make this value a negative number [Eg.: -1]).

Example:

_friends = [_f1, _f2, _f3, _f4]
_enemies = [_e1, _e2, _e3, _e4]
_info = [_friends, _enemies, .5, 250]

_i1 = _info select 0
_i2 = _info select 1

This will sort the knowlege that each member of _friends has about each member of _enemies
any _friends that have knowledge greater than .5 of one or more of the _enemies will be included in
the array list _i1 along with which unit he knows the most about and how much knowledge he has of
that unit.  Also, since the max range (250) is not negative.  The units known by any of the _friends
(if the knowledge is greater than .5) will be revealed to all other members of _friends (via the group leaders)
that are within 250 meters of that unit.  The array _i2 will contain a list of arrays of those _enemies that
are known by .5 or more and which units know most about each of these, and how much he knows.

If all the units among friends know more than .5 about all the _enemies then _i1 might look like this:

_i1 : [ [_f2, _e1, 2.5], [_f4, _e3, 1.5], [_f1, _e2, 1.2], [_f3, _e4, .51] ]

and then _i2 would look like this:

_i2 : [ [_e1, _f2, 2.5], [_e3, _f4, 1.5], [_e2, _f1, 1.2], [_e4, _f3, .51] ]

But, if the _friends only know about one of the units in _enemies then the arrays would look like this:

_i1 : [ [_f4, _e3, 2.1], [_f1, _e3, 1.3], [_f2, _e3, 1.2], [_f3, _e3, .65] ]
_i2 : [ [_e3, _f4, 2.1] ]

If only one of the _friends knows about all the enemies then the arrays would be like this:

_i1 : [ [_f4, _e3, 2.2] ]
_i2 : [ [_e3, _f4, 2.2], [_e1, _f4, 1.7], [_e2, _f4, 1.1], [_e4, _f4, .92] ]

Since only _f4 has knowledge of enemies, _i1 only has one array element.

Initialize this function by putting this in your init.sqs:
revealInfo = preprocessFile "revealInfo.sqf"

---------------------------------------------------------------*/

private ["_unit", "_frnds", "_enems","_dis","_cnt","_kmin","_knowers","_knowns","_krec","_cnt2"];
private ["_list","_elem", "_elemrec", "_cnt3", "_knower", "_known","_leads","_erec","_friends", "_enemies"];

_friends = _this select 0;
_enemies = _this select 1;
_kmin = _this select 2;
_dis = _this select 3;

//make sure only living units are in array pools
_frnds = [];
{ if (alive _x) then {_frnds = _frnds + [_x]} } forEach _friends;
_enems = [];
{ if (alive _x) then {_enems = _enems + [_x]} } forEach _enemies;

//make array of friends who know at least _kmin about an enemy

_knowers = [];
_cnt = 0;
While {_cnt < count _frnds}
Do
	{
	_unit = _frnds select _cnt;
	if ( {(_unit knowsAbout _x) >= _kmin} count _enems > 0 ) then { _knowers = _knowers + [_unit] };
	_cnt = _cnt + 1;
	};

//make array of enemies who are know at least _kmin by a _knower

_knowns = [];
_cnt = 0;
While {_cnt < count _enems}
Do
	{
	_unit = _enems select _cnt;
	if ( {(_x knowsAbout _unit) >= _kmin} count _knowers > 0 ) then { _knowns = _knowns + [_unit]};
	_cnt = _cnt + 1;
	};

// Make knowers array list

_list = [];
_cnt = 0;
While {_cnt < count _knowers && count _knowers > 0}
Do
	{
	_unit = _knowers select _cnt;
	_krec = 0;
	_cnt2 = 0;
	While {_cnt2 < count _knowns}
	Do
		{
		_know = _unit knowsAbout (_knowns select _cnt2);
		if ( _know > _krec )
		then 
			{
			_list set [_cnt , [_unit, (_knowns select _cnt2) , _know] ];
			_krec = _know;
			};
		_cnt2 = _cnt2 + 1;
		};
	_cnt = _cnt + 1;
	};

//Sort knowers array list

_knowersList = [];
_cnt2 = 0;
While {_cnt2 < count _list}
Do
	{
	_krec = 0;
	_erec = 0;
	_elem = [];
	_cnt = 0;
	While {_cnt < count _list}
	Do
		{
		_elem = _list select _cnt;
		if ( (_elem select 2) > _krec )
		then 
			{
			_knowersList set [_cnt2 , _elem];
			_krec = (_elem select 2);
			_erec = _cnt;
			};
		_cnt = _cnt + 1;
		};
	_list set [_erec, ["","",0]];
	_cnt2 = count _knowersList;
	};

// Make knowns array list

_list = [];
_cnt = 0;
While {_cnt < count _knowns && count _knowns > 0}
Do
	{
	_unit = _knowns select _cnt;
	_krec = 0;
	_cnt2 = 0;
	While {_cnt2 < count _knowers}
	Do
		{
		_know = (_knowers select _cnt2) knowsAbout _unit;
		if ( _know > _krec )
		then 
			{
			_list set [_cnt , [_unit, (_knowers select _cnt2) , _know] ];
			_krec = _know;
			};
		_cnt2 = _cnt2 + 1;
		};
	_cnt = _cnt + 1;
	};

//Sort knowns array list

_knownsList = [];
_cnt2 = 0;
While {_cnt2 < count _list}
Do
	{
	_krec = 0;
	_erec = 0;
	_elem = [];
	_cnt = 0;
	While {_cnt < count _list}
	Do
		{
		_elem = _list select _cnt;
		if ( (_elem select 2) > _krec )
		then 
			{
			_knownsList set [_cnt2 , _elem];
			_krec = (_elem select 2);
			_erec = _cnt;
			};
		_cnt = _cnt + 1;
		};
	_list set [_erec, ["","",0]];
	_cnt2 = count _knownsList;
	};

//Reveal known units to other friendly leaders.

_leads = [];
{ if ( (_x == leader (group _x)) && (alive _x) ) then {_leads = _leads + [_x]} } forEach _frnds;

_cnt = 0;
While {_cnt < count _leads}
Do
	{
	_unit = _leads select _cnt;
	_cnt2 = 0;
	While {_cnt2 < count _knowers}
	Do
		{
		_knower = _knowers select _cnt2;
		_cnt3 = 0;
		While {_cnt3 < count _knowns}
		Do
			{
			_known = _knowns select _cnt3;
			If ( (_unit distance _knower) <= _dis && (_knower knowsAbout _known) >= _kmin) then {_unit reveal _known};
			_cnt3 = _cnt3 + 1;
			};
		_cnt2 = _cnt2 + 1;
		};
	_cnt = _cnt + 1;
	};
[_knowersList, _knownsList]