/*---------------------------------------------------------------
shoreLine function by Raptorsaurus (version 1.00, July 3, 2010)

Returns true if part of a circular area surrounding an object or position is over water and part of
the area is over land.

Parameters:

Postition or Object
	Pass the object name in array brackets [objname] or position (3 [x,y,z]
	or  2 [x,y] dim format) to the function.
Radius
	The radius of the area to check surrounding the position or object (minimum radius is 5 m).
Distance
	The distance between check points (minimum distance is 1 m).

Examples:

_shoreline = [[_boat], 20, 5] call shoreLine
_shoreline = [(getPos _boat), 5, 1] call shoreLine
_shoreline = [[124, 1345.10], 10, 2] call shoreLine

Initialize this function by putting this in your init.sqs:
shoreLine = preprocessFile "shoreLine.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_input", "_pos" , "_SLref", "_GLref","_tASL", "_tide", "_water", "_land","_shore","_rad", "_inc", "_radcnt", "_dir", "_X", "_Z", "_dis"];

_input = _this select 0;
_rad = abs (_this select 1);
_dis = abs (_this select 2);
if (_dis < 1) then {_dis = 1};
if (_rad < 5) then {_rad = 5};
if (count _input == 1) then {_pos = [(getPos (_input select 0)) select 0, (getPos (_input select 0)) select 1]};
if (count _input > 1) then {_pos = [_input select 0, _input select 1]};
_X = _pos select 0;
_Y = _pos select 1;
_water = false;
_land = false;
_shore = false;

// Put Sea level reference and ground level reference, calculate tidal offset
_SLref = "emptyDetector" camcreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];
_SLref setPos [0,0];
_GLref setPos [0,0,0];
_tide = _GLref distance _SLref;

_inc = 0;
_radcnt = 0;

While {_radcnt <= _rad && ! _shore}
Do
{
	if (_radcnt > 0) then {_inc = 360 / ( (360 / Asin (_dis/_radcnt)) - ((360 / Asin (_dis/_radcnt)) % 1) )};
	_dir = 0;
	While {_dir < 360 && ! _shore}
	Do
	{
		_pos = [(_X + (_radcnt * Sin _dir)), (_Y + (_radcnt * Cos _dir))];
		_SLref setPos _pos;
		_GLref setPos [_pos select 0, _pos select 1, 0];
		_tASL = _GLref distance _SLref;
		if (abs (_tASL - _tide) < .01) then {_water = true} else {_land = true};
		if (_water && _land) then {_shore = true};
		if (_inc > 0) then {_dir = _dir + _inc} else {_dir = 360};
	};
	_radcnt = _radcnt + _dis;
};

deleteVehicle _SLref;
deleteVehicle _GLref;

_shore