/*---------------------------------------------------------------
waterPath function by Raptorsaurus (version 1.00, July. 25, 2010)

Given a starting position, an ending position, and a path width, this function determines
if the path is entirely over water. If the path is entirely over water, the function
returns a boolean true and the path distance [true, distance], otherwise false and the
distance at which land was encountered [false, distance].

Parameters:

Starting position
	3d [x,y,z] or 2d [x,y] position.
Ending position
	3d [x,y,z] or 2d [x,y] position.
Path width
	The width of the path to check. The step increments will be half of the path width.

Example: _poverWater = [getPos plane, getPos ship, 20] call waterPath

Initialize this function by putting this in your init.sqs:
waterPath = preprocessFile "waterPath.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_spos", "_epos" , "_SLref", "_GLref","_tASL", "_tide", "_water", "_rad", "_inc","_wpos"];
private ["_radcnt", "_dir", "_X", "_Y", "_dis", "_pdir","_pos","_Dx","_Dy","_pdis","_width","_dinc"];

_spos = _this select 0;
_epos = _this select 1;
_width = abs (_this select 2);
if (_width < 1) then {_width = 1};

// Determine direction, distance and step increments
_Dx = (_epos select 0) - (_spos select 0);
_Dy = (_epos select 1) - (_spos select 1);
if (_Dy == 0) then {_Dy = .0000001};
_pdir = _Dx atan2 _Dy;
if (_pdir < 0) then {_pdir = _pdir + 360};
_pdis = sqrt (_Dx^2 + _Dy^2);

// optimize check increments
_rad = _width / 2;
_inc = _width / 2;
_inc = _pdis / ((_pdis/_inc) - ((_pdis/_inc) % 1));

// Put Sea level reference and ground level reference, calculate tidal offset
_SLref = "emptyDetector" camcreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];
_SLref setPos [0,0];
_GLref setPos [0,0,0];
_tide = _GLref distance _SLref;
_water = true;

//Check linear path to determine over water status
_dis = 0;
While {_dis < _pdis && _water}
Do
{
	_pos = [(_spos select 0) + (_dis * sin _pdir), (_spos select 1) + (_dis * cos _pdir), 0];

	//Check center and edge of area for being over water
	_X = _pos select 0;
	_Y = _pos select 1;
	_dinc = 0;
	_radcnt = 0;
	While {_radcnt <= _rad && _water}
	Do
	{
		if (_radcnt > 0) then {_dinc = 180};
		_dir = _pdir - 90;
		While {_dir <= (_pdir + 90) && _water}
		Do
		{
			_wpos = [(_X + (_radcnt * Sin _dir)), (_Y + (_radcnt * Cos _dir))];
			_SLref setPos _wpos;
			_GLref setPos [_wpos select 0, _wpos select 1, 0];
			_tASL = _GLref distance _SLref;
			if (abs (_tASL - _tide) >= .01) then {_water = false};
			if (_dinc > 0) then {_dir = _dir + _dinc} else {_dir = _pdir + 180};
		};
		_radcnt = _radcnt + _rad;
	};
	_dis = _dis + _inc;
};
deleteVehicle _SLref;
deleteVehicle _GLref;
[_water, _dis]