/*---------------------------------------------------------------
waterPosDir function by Raptorsaurus (version 1.00, July. 25, 2010)

Given a starting position, an initial check direction, check direction increment, check distance and radius of check area, this
function returns the first position and the direction to that position in which the entire check radius is over water. If an over water
position is not found, then the returned value will be an empty array.

Parameters:

Postition or Object
	Pass the object name in array brackets [objname] or position (3 [x,y,z]
	or  2 [x,y] dim format) to the function.
Start Direction
	The starting direction to check for the first entirely over water area
Direction Increment
	The directional increment in degrees (positive to check clockwise, negative to check counter clockwise).
Distance
	The distance from the reference position to the center of the check areas.
Radius
	The radius of the area that must be entirely over water.


Examples:

_pos_dir = [[_Plane], 20, 30, 100, 25] call waterPosDir
_pos_dir = [(getPos _plane), 0, 10, 500, 25] call waterPosDir
_pos_dir = [[124, 1345.10], 0, 45, 150, 25] call waterPosDir

Initialize this function by putting this in your init.sqs:
waterPosDir = preprocessFile "waterPosDir.sqf"
---------------------------------------------------------------*/

// declare private variables
private ["_input", "_refpos" , "_SLref", "_GLref","_tASL", "_tide", "_water", "_rad", "_inc","_wpos"];
private ["_radcnt", "_dir", "_X", "_Z", "_dis", "_idir", "_dirInc","_ckdir","_reldir","_pos","_val"];

_input = _this select 0;
_idir = _this select 1;
_dirInc = _this select 2;
_dis = abs (_this select 3);
_rad = abs (_this select 4);
if (_dis == 0) then {_dis = 1};
if (_dirInc == 0) then {_dirInc = 1};
if (count _input == 1) then {_refpos = [(getPos (_input select 0)) select 0, (getPos (_input select 0)) select 1]};
if (count _input > 1) then {_refpos = [_input select 0, _input select 1]};

// Put Sea level reference and ground level reference, calculate tidal offset
_SLref = "emptyDetector" camcreate [0,0,0];
_GLref = "logic" camcreate [0,0,0];
_SLref setPos [0,0];
_GLref setPos [0,0,0];
_tide = _GLref distance _SLref;

//Cycle through check positions until an enitely over water area is found
_val = [];
_reldir = 0;
While {abs _reldir < 360 && count _val == 0}
Do
{
	_ckdir = _reldir + _idir;
	_pos = [(_refpos select 0) + (_dis * sin _ckdir), (_refpos select 1) + (_dis * cos _ckdir), 0];

	//Check center and edge of area for being over water
	_X = _pos select 0;
	_Y = _pos select 1;
	_inc = 0;
	_radcnt = 0;
	_water = true;
	While {_radcnt <= _rad && _water}
	Do
	{
		if (_radcnt > 0) then {_inc = 10};
		_dir = 0;
		While {_dir < 360 && _water}
		Do
		{
			_wpos = [(_X + (_radcnt * Sin _dir)), (_Y + (_radcnt * Cos _dir))];
			_SLref setPos _wpos;
			_GLref setPos [_wpos select 0, _wpos select 1, 0];
			_tASL = _GLref distance _SLref;
			if (abs (_tASL - _tide) >= .01) then {_water = false};
			if (_inc > 0) then {_dir = _dir + _inc} else {_dir = 360};
		};
		_radcnt = _radcnt + _rad;
	};
	if (_water) then {_val = [_pos, _ckdir]};
	_reldir = _reldir + _dirInc;
};
deleteVehicle _SLref;
deleteVehicle _GLref;
_val